#line 2 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pyscanner.cpp"

#line 4 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pyscanner.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer pyscannerYY_create_buffer
#define yy_delete_buffer pyscannerYY_delete_buffer
#define yy_flex_debug pyscannerYY_flex_debug
#define yy_init_buffer pyscannerYY_init_buffer
#define yy_flush_buffer pyscannerYY_flush_buffer
#define yy_load_buffer_state pyscannerYY_load_buffer_state
#define yy_switch_to_buffer pyscannerYY_switch_to_buffer
#define yyin pyscannerYYin
#define yyleng pyscannerYYleng
#define yylex pyscannerYYlex
#define yylineno pyscannerYYlineno
#define yyout pyscannerYYout
#define yyrestart pyscannerYYrestart
#define yytext pyscannerYYtext
#define yywrap pyscannerYYwrap
#define yyalloc pyscannerYYalloc
#define yyrealloc pyscannerYYrealloc
#define yyfree pyscannerYYfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE pyscannerYYrestart(pyscannerYYin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t pyscannerYYleng;

extern FILE *pyscannerYYin, *pyscannerYYout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pyscannerYYtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via pyscannerYYrestart()), so that the user can continue scanning by
	 * just pointing pyscannerYYin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when pyscannerYYtext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t pyscannerYYleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow pyscannerYYwrap()'s to do buffer switches
 * instead of setting up a fresh pyscannerYYin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void pyscannerYYrestart (FILE *input_file  );
void pyscannerYY_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE pyscannerYY_create_buffer (FILE *file,int size  );
void pyscannerYY_delete_buffer (YY_BUFFER_STATE b  );
void pyscannerYY_flush_buffer (YY_BUFFER_STATE b  );
void pyscannerYYpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void pyscannerYYpop_buffer_state (void );

static void pyscannerYYensure_buffer_stack (void );
static void pyscannerYY_load_buffer_state (void );
static void pyscannerYY_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER pyscannerYY_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE pyscannerYY_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE pyscannerYY_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE pyscannerYY_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *pyscannerYYalloc (yy_size_t  );
void *pyscannerYYrealloc (void *,yy_size_t  );
void pyscannerYYfree (void *  );

#define yy_new_buffer pyscannerYY_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        pyscannerYYensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pyscannerYY_create_buffer(pyscannerYYin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        pyscannerYYensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pyscannerYY_create_buffer(pyscannerYYin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define pyscannerYYwrap() 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *pyscannerYYin = (FILE *) 0, *pyscannerYYout = (FILE *) 0;

typedef int yy_state_type;

extern int pyscannerYYlineno;

int pyscannerYYlineno = 1;

extern char *pyscannerYYtext;
#define yytext_ptr pyscannerYYtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up pyscannerYYtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	pyscannerYYleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 163
#define YY_END_OF_BUFFER 164
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[881] =
    {   0,
    16488,16488,  106,  106,   30,   30,   36,   36,   41,   41,
      164,  162,  163,  161,  163,   25,  162,  163,   25,  162,
      163,   19,  161,  163,   13,   25,  162,  163,   25,  162,
      163,   12,   25,  162,  163,   23,   25,  162,  163,   24,
       25,  162,  163,   25,  162,  163,   17,   25,  162,  163,
    16395,   17,   25,  162,  163,16395,   17,   25,  162,  163,
    16395,   17,   25,  162,  163,16395,   17,   25,  162,  163,
    16395,   18,   25,  162,  163,   17,   25,  162,  163,16393,
    16394,16395,   17,   25,  162,  163,16393,16394,16395,   17,
       25,  162,  163,16393,16394,16395,   17,   25,  162,  163,

    16393,16394,16395,   17,   25,  162,  163,16393,16394,16395,
       53,   54,  162,  163,   51,  161,  163,   50,   54,  162,
      163,   54,  162,  163,   49,   54,  162,  163,   54,  162,
      163,   52,   54,  162,  163,   52,   54,  162,  163,   52,
       54,  162,  163,   52,   53,   54,  162,  163,  135,  138,
      162,  163,  138,  162,  163,  136,  161,  163,  138,  162,
      163,  138,  162,  163,  138,  162,  163,  134,  138,  162,
      163,  141,  143,  162,  163,  142,  161,  163,  143,  162,
      163,  141,  143,  162,  163,  139,  143,  162,  163,  162,
      163,   71,  162,  163,   70,  162,  163,   69,  162,  163,

       78,  162,  163,   72,  162,  163,   78,  162,  163,   75,
      162,  163,   72,   78,  162,  163,   76,  162,  163,   74,
       78,  162,  163,   73,   78,  162,  163,   61,   65,  162,
      163,   65,  162,  163,   64,  161,  163,16439,   60,   65,
      162,  163,   63,   65,  162,  163,   59,   65,  162,  163,
       58,   65,  162,  163,   63,   65,  162,  163,   82,  162,
      163,   83,  161,  163,   79,   82,  162,  163,   81,   82,
      162,  163,   80,   82,  162,  163,   96,  162,  163,   97,
      162,  163,   97,  162,  163,   98,  162,  163,   99,  162,
      163,  162,  163,  100,  161,  163, 8296,  162,  163,  162,

      163,  162,  163,  103,  162,  163,   90,   93,  162,  163,
       93,  162,  163,   91,  161,  163,   89,   93,  162,  163,
       93,  162,  163,   88,   93,  162,  163,   87,   93,  162,
      163,  119,  162,  163,  106,  119,  162,  163,  120,  161,
      163,  111,  119,  162,  163,  117,  119,  162,  163,  110,
      119,  162,  163,  114,  119,  162,  163,  107,  119,  162,
      163,  107,  119,  162,  163,  105,  119,  162,  163,  118,
      119,  162,  163,  118,  119,  162,  163,  118,  119,  162,
      163,  118,  119,  162,  163,  118,  119,  162,  163,  115,
      119,  162,  163,  118,  119,  162,  163,  116,  119,  162,

      163,  131,  162,  163,  130,  161,  163,  128,  162,  163,
      129,  161,  163,  126,  128,  162,  163,  125,  128,  162,
      163,  121,  128,  162,  163,  122,  128,  162,  163,  127,
      128,  162,  163,  148,  149,  162,  163,  149,  162,  163,
      147,  149,  162,  163,  149,  162,  163,  154,  155,  162,
      163,  153,  155,  162,  163,  155,  162,  163,  155,  162,
      163,  158,  160,  162,  163,  158,  159,  161,  163,  158,
      160,  162,  163,  158,  160,  162,  163,  160,  162,  163,
       31,  162,  163,   30,   31,  162,  163,   29,  161,  163,
       26,   31,  162,  163,   27,   31,  162,  163,   27,   31,

      162,  163,   38,  162,  163,   36,   38,  162,  163,   35,
      161,  163,   32,   38,  162,  163,   37,   38,  162,  163,
       34,   38,  162,  163,16417,   42,  162,  163,   41,   42,
      162,  163,   40,  161,  163,   39,   42,  162,  163,16395,
       19,   16,   15,   16,   17,16395,   17,16395,   17,16395,
       17,16395,   17,16395,   18,16393,16394,16395,16393,16394,
    16395,16393,16394,16395,16393,16394,16395,16393,16394,16395,
       17,16393,16394,16395,   17,16393,16394,16395,   17,16393,
    16394,16395,   17,16393,16394,16395,   17,16393,16394,16395,
       53,   48,   52,   52,   52,   52,   53,  135,  137,  134,

      141,  140,  141,  139,  139,   71,   70,   69,   72,   77,
       76,   73,   61,16439,   63,   63,   58,   57,   62,   63,
       96,   97,   99,  100,  103,   90,   92,   87,   86,  106,
      117,  107,  107,  107,  118,  118,  111,  110,  118,  118,
      127,  148,  145,  145,  144,  154,  151,  151,  150,  158,
      158,  158,   30,   27,   27,   36, 8225,   34,16417,   41,
       39,16395,   20,   16,   15,   16,   22,   21, 8203,   17,
    16395,   17,16395,   17,16395,   17,16395,16393,16394,16395,
    16393,16394,16395,16393,16394,16395,16393,16394,16395,16393,
    16394,16395, 8202, 8203, 8202, 8203, 8202, 8203,   17,16393,

    16394,16395,   17,16393,16394,16395,   17,16393,16394,16395,
       17,16393,16394,16395,   45,   48,   47,   46,   52,   52,
      132,  133,   77,   56, 8247,   66,   63,   68,   68,   67,
       62,   63,   99,  101,  102,   84,   94,   92,   95,  112,
      113,  108,  107,  107,  118,  118,  123,  124,  146,  152,
      156,  157,   27,   27, 8225,   39,   20,   21,   17,16395,
        2,   17,16395,   17,16395,16393,16394,16395,16393,16394,
    16395,16393,16394,16395,16393,16394,16395,   17,16393,16394,
    16395,    1,    2,   17,16393,16394,16395,   17,16393,16394,
    16395,   45,   46,   52,  132,  133,   66,   67,   99,  101,

      102,   85,   94,   95,  112,  113,  108,  107,  118,  109,
      118,  123,  124,  156,  157,   27,   27,   39,   17,16395,
        6,   17,16395,16393,16394,16395,    1,16393,16394,16395,
    16393,16394,16395,   17,16393,16394,16395,    5,    6,   17,
    16393,16394,16395,16428,  108,   27,    4,   17,16395,16393,
    16394,16395,    5,16393,16394,16395,    3,    4,   17,16393,
    16394,16395,16428, 8236,16427,   27,   28,    8,    3,16393,
    16394,16395,    7,    8,16427, 8235,   28,    7, 8201,   14
    } ;

static yyconst flex_int16_t yy_accept[497] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    2,    3,    3,    3,    4,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    6,    7,    8,    9,   10,   11,   12,   14,   16,
       19,   22,   25,   29,   32,   36,   40,   44,   47,   52,
       57,   62,   67,   72,   76,   83,   90,   97,  104,  111,
      115,  118,  122,  125,  129,  132,  136,  140,  144,  149,
      153,  156,  159,  162,  165,  168,  172,  176,  179,  182,
      186,  190,  192,  195,  198,  201,  204,  207,  210,  213,

      217,  220,  224,  228,  232,  235,  239,  243,  247,  251,
      255,  259,  262,  265,  269,  273,  277,  280,  283,  286,
      289,  292,  294,  297,  300,  302,  304,  307,  311,  314,
      317,  321,  324,  328,  332,  335,  339,  342,  346,  350,
      354,  358,  362,  366,  370,  374,  378,  382,  386,  390,
      394,  398,  402,  405,  408,  411,  414,  418,  422,  426,
      430,  434,  438,  441,  445,  448,  452,  456,  459,  462,
      466,  470,  474,  478,  481,  484,  488,  491,  495,  499,
      503,  506,  510,  513,  517,  521,  526,  529,  533,  536,
      540,  540,  541,  542,  542,  543,  545,  545,  545,  545,

      545,  545,  545,  547,  547,  549,  551,  553,  555,  556,
      559,  562,  565,  568,  571,  571,  575,  575,  579,  583,
      587,  591,  592,  592,  593,  593,  593,  594,  595,  596,
      598,  599,  599,  599,  600,  601,  602,  602,  603,  604,
      605,  606,  606,  607,  608,  609,  610,  611,  612,  613,
      614,  615,  615,  615,  615,  616,  617,  617,  618,  619,
      621,  622,  623,  623,  624,  624,  625,  625,  625,  626,
      627,  627,  627,  627,  628,  628,  629,  630,  631,  631,
      632,  632,  632,  633,  634,  635,  635,  636,  637,  638,
      639,  640,  641,  641,  641,  642,  643,  643,  644,  645,

      646,  647,  647,  648,  649,  650,  651,  651,  652,  653,
      654,  654,  654,  655,  656,  657,  657,  658,  660,  661,
      661,  661,  662,  663,  664,  665,  667,  668,  669,  669,
      669,  669,  669,  670,  672,  674,  676,  678,  681,  684,
      687,  690,  693,  695,  697,  699,  703,  707,  711,  715,
      716,  717,  718,  719,  720,  721,  722,  723,  724,  725,
      726,  726,  727,  729,  730,  731,  733,  734,  735,  736,
      736,  737,  737,  738,  739,  740,  741,  742,  743,  744,
      745,  746,  747,  748,  749,  750,  750,  751,  751,  752,
      753,  753,  754,  755,  756,  756,  757,  758,  759,  759,

      759,  761,  762,  764,  766,  769,  772,  775,  778,  778,
      778,  778,  782,  784,  788,  792,  793,  794,  794,  795,
      796,  797,  798,  799,  800,  801,  802,  803,  804,  805,
      806,  807,  807,  808,  809,  810,  812,  813,  814,  815,
      816,  817,  818,  819,  819,  821,  822,  824,  827,  828,
      831,  834,  834,  838,  840,  844,  845,  845,  845,  846,
      847,  847,  848,  850,  853,  854,  857,  857,  859,  863,
      863,  864,  865,  866,  868,  868,  869,  870,  873,  873,
      875,  875,  876,  877,  878,  878,  879,  879,  879,  879,
      879,  880,  880,  880,  881,  881

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    1,    7,    7,    8,    9,
       10,   11,   12,   13,   12,   14,    7,   15,   16,   16,
       16,   16,   16,   16,   16,   17,   17,   18,    7,    7,
       19,    7,    1,   20,   21,   21,   21,   21,   22,   23,
       24,   24,   24,   25,   24,   26,   24,   24,   24,   24,
       24,   27,   24,   28,   29,   24,   24,   30,   24,   24,
       31,   32,   33,    1,   34,    7,   35,   21,   36,   37,

       38,   39,   24,   40,   41,   25,   24,   42,   43,   24,
       44,   45,   24,   46,   47,   48,   49,   24,   24,   30,
       50,   24,   51,    7,   33,    7,    1,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,

       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52
    } ;

static yyconst flex_int32_t yy_meta[53] =
    {   0,
        1,    2,    3,    1,    4,    5,    1,    4,    1,    6,
        1,    1,    7,    8,    9,    9,    9,    1,   10,    1,
       11,   11,   11,   12,   12,   12,   12,   12,   12,   12,
        1,   13,    1,   12,   11,   11,   11,   11,   11,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
        1,   14
    } ;

static yyconst flex_int16_t yy_base[603] =
    {   0,
     1766, 1763,    0,   52,  104,    0, 1760, 1756,  155,  159,
      162,  167,  191,    0,  243,    0,  169,  176,  293,  295,
      308,    0,  360,    0,  412,  420,  428,  436,  444,    0,
     1753, 1740,  496,    0,  546,  547,  553,  554,  560,  561,
      593,    0,  645,    0,  697,    0, 1729, 2672, 2672, 2672,
     1723, 1719, 1716,  182, 1712, 2672, 2672, 1672,  416,  748,
      749,  750,  762,  752,  570,  764,  763,  784,  797,    0,
     2672, 1713, 1710, 1707, 2672,    0, 1665, 1666,  840,    0,
     2672, 2672, 1698, 1694,    0, 1699,    0,  174, 2672,  183,
     1692,  558, 2672, 2672,    0, 2672, 1693,    0, 2672, 2672,

     1682, 2672,    0,    0, 2672,  295, 1677, 1672, 1667,  297,
     1658, 2672, 2672, 2672, 2672, 2672,    0, 1660, 2672, 2672,
     1634,  568, 2672, 2672, 1639, 1627,  571,    0, 2672, 1628,
     1628,    0, 1622,  579, 2672, 1625, 2672, 1609,    0, 1601,
     2672,  879,  797, 2672,    0, 1573,  411, 1559,  790, 2672,
      816, 2672, 2672, 2672, 2672, 2672, 1597, 1593, 2672, 2672,
        0,    0, 1595, 2672,  585,    0, 2672, 1588,  588, 1559,
     1556, 1582, 1578,  823, 2672, 1581, 2672, 2672,  778,  818,
     2672, 1578, 2672, 2672, 2672,  802, 2672, 1577, 2672,  823,
     1576,  864, 1574, 1571,    0,    0,    0, 1567, 1526,  865,

      844, 1571,  866,    0,  887,  888,  900,  901,  897,  913,
      929,  939,  941,  943,  953,  955,  755,  957,  971,  978,
      983,    0, 1565,    0,    0, 1557,    0, 1515, 1519, 1028,
        0, 1555, 1539, 2672, 1541,    0,  827, 2672,  832, 1534,
     1533,  800, 2672, 2672,    0, 1536,    0, 1535,    0,    0,
      863, 1530, 1533, 1529,    0,  421, 1525,  753, 2672,    0,
        0, 1373,    0, 1360,  768, 2672, 1368, 1364,  776,    0,
     1363, 1364, 1357,    0, 1353,  782, 2672, 1354, 1348,    0,
     1344,  865,  989, 1039, 2672,    0,    0, 1306, 2672, 2672,
     1290,  840, 1333, 1329,    0,    0, 1323, 2672,  884, 2672,

        0, 1317, 2672,  914, 2672, 1292,  932, 1318, 1312, 1308,
      910, 1307,  916,  980, 1304,  806, 1301,  948, 1292,  981,
     1286,  987,  998, 1282,    0,    0, 2672, 1278, 1244,  906,
     1274, 1014, 2672, 1056, 1072, 1074, 1076, 1086, 1088, 1100,
     1102, 1112, 2672,  825, 1229, 1114, 1116, 1128, 1130, 1270,
        0, 2672, 1265, 1251,  984, 1244, 1243,    0, 2672, 1239,
     1236, 1230,    0, 2672, 1225,    0, 1194, 1185, 1184,    0,
     1181, 1158, 1154,    0, 1146, 1140, 1133, 1137, 2672,  992,
     1089, 1070, 1088, 1073, 2672,  926, 2672,  976, 1069, 1064,
     1061, 1005, 1007, 1055, 1050, 1048, 2672, 2672, 1001, 1132,

     1153, 1154, 1166, 1167, 1168, 1180, 1182, 1192,  967,  996,
      992, 1204, 1208, 1218, 1220, 2672, 2672,    0, 1012, 2672,
     2672, 2672, 2672, 1006, 2672, 2672, 2672, 2672, 2672, 2672,
     2672, 1055, 2672, 2672,  975,    0, 2672, 2672, 2672, 2672,
     1092, 1189, 1095,  958, 1230, 1240, 1242, 1244, 1254, 1258,
     1268,  930, 1270, 1282, 1283,  945,    0, 1181, 1282, 1210,
      852, 1298, 1302, 1303, 1316, 1317,  826, 1330, 1331, 1081,
     1109, 2672, 1146, 1202,  792, 1332, 1344, 1345,  707, 1357,
     1207, 1243, 2672, 1205,  546, 1358,  505,  395,  387,  267,
     2672,  122,  122, 2672, 2672, 1377, 1391, 1405, 1419, 1433,

     1447, 1461, 1475, 1489, 1503, 1517, 1530, 1544, 1557, 1570,
     1583, 1597, 1611, 1617, 1631, 1645, 1659, 1665, 1679, 1685,
     1699, 1712, 1726, 1740, 1746, 1753, 1767, 1777, 1791, 1805,
     1811, 1817, 1831, 1845, 1859, 1873, 1887, 1900, 1913, 1926,
     1939, 1953, 1967, 1981, 1994, 2007, 2021, 2034, 2047, 2060,
     2074, 2088, 2102, 2116, 2122, 2136, 2150, 2156, 2170, 2176,
     2190, 2203, 2216, 2230, 2244, 2258, 2264, 2268, 2275, 2289,
     2302, 2316, 2330,  566, 2336, 2342, 2356, 2370, 2384, 2397,
     2410, 2423, 2436, 2449, 2462, 2476, 2490, 2503, 2516, 2529,
     2542, 2555, 2569, 2576, 2583, 2597, 2610, 2623, 2627, 2640,

     2644, 2657
    } ;

static yyconst flex_int16_t yy_def[603] =
    {   0,
      496,  496,  495,  495,  495,    5,  496,  496,  497,  497,
      498,  498,  495,   13,  495,   15,  499,  499,  500,  500,
      495,   21,  495,   23,  501,  501,  502,  502,  495,   29,
      503,  503,  495,   33,  504,  504,  505,  505,  506,  506,
      495,   41,  495,   43,  495,   45,  495,  495,  495,  495,
      507,  495,  495,  508,  495,  495,  495,  495,  509,  509,
      509,  509,  509,  510,  511,  511,  511,  511,  511,  512,
      495,  495,  513,  495,  495,  514,  514,  514,  514,  515,
      495,  495,  495,  495,  516,  495,  517,  495,  495,  517,
      495,  495,  495,  495,  518,  495,  495,  519,  495,  495,

      495,  495,  520,  521,  495,  522,  495,  523,  495,  495,
      524,  495,  495,  495,  495,  495,  525,  495,  495,  495,
      526,  495,  495,  495,  495,  495,  495,  527,  495,  528,
      495,  529,  495,  495,  495,  495,  495,  495,  530,  495,
      495,  495,  495,  495,  531,  531,  531,  531,  531,  495,
      531,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      532,  533,  495,  495,  534,  535,  495,  495,  536,  537,
      537,  495,  495,  537,  495,  495,  495,  495,  538,  538,
      495,  495,  495,  495,  495,  539,  495,  495,  495,  540,
      507,  541,  495,  495,  542,  543,  544,  495,  495,  495,

      495,  545,  546,  547,  546,  546,  546,  546,  548,  549,
      549,  549,  549,  549,  495,  550,  551,  550,  550,  550,
      550,  552,  495,  553,  554,  495,  555,  555,  555,  555,
      556,  495,  495,  495,  495,  557,  495,  495,  557,  495,
      495,  495,  495,  495,  558,  495,  559,  495,  560,  561,
      562,  495,  563,  495,  564,  565,  495,  495,  495,  566,
      567,  495,  568,  569,  495,  495,  495,  495,  495,  570,
      495,  571,  495,  572,  495,  495,  495,  495,  495,  573,
      495,  495,  495,  495,  495,  574,  575,  575,  495,  495,
      575,  575,  495,  495,  576,  577,  495,  495,  495,  495,

      578,  495,  495,  495,  495,  579,  579,  495,  495,  495,
      495,  580,  581,  581,  495,  495,  495,  582,  495,  495,
      583,  584,  585,  495,  586,  587,  495,  495,  495,  495,
      588,  589,  495,  590,  590,  590,  590,  591,  591,  591,
      591,  591,  495,  495,  495,  592,  592,  592,  592,  495,
      593,  495,  495,  594,  594,  495,  495,  559,  495,  495,
      563,  495,  564,  495,  495,  566,  595,  495,  495,  596,
      495,  571,  495,  572,  495,  495,  495,  495,  495,  574,
      575,  575,  495,  495,  495,  495,  495,  495,  495,  495,
      580,  597,  581,  495,  583,  598,  495,  495,  495,  589,

      590,  495,  590,  590,  591,  591,  591,  591,  495,  495,
      495,  592,  495,  592,  592,  495,  495,  599,  594,  495,
      495,  495,  495,  595,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  575,  575,  495,  495,  495,  495,
      597,  581,  598,  495,  590,  495,  590,  591,  495,  591,
      591,  495,  592,  495,  592,  600,  601,  495,  495,  581,
      495,  495,  590,  591,  495,  591,  495,  495,  592,  495,
      600,  495,  602,  581,  495,  495,  495,  591,  495,  495,
      495,  602,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,    0,  495,  495,  495,  495,  495,

      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,

      495,  495
    } ;

static yyconst flex_int16_t yy_nxt[2725] =
    {   0,
       50,   51,   52,   50,   53,   54,   50,   55,   56,   57,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   58,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       50,   50,   50,   59,   59,   60,   61,   59,   62,   59,
       63,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       50,   59,   50,   64,   52,   50,   53,   54,   50,   55,
       56,   57,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   58,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   50,   50,   50,   65,   65,   66,   67,   65,
       68,   65,   69,   65,   65,   65,   65,   65,   65,   65,

       65,   65,   50,   65,   70,   70,   71,   70,   72,   73,
       70,   74,   70,   70,   70,   70,   70,   75,   70,   70,
       70,   70,   70,   70,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   70,   70,   70,   76,   76,   77,
       76,   76,   76,   76,   76,   76,   76,   76,   76,   76,
       78,   76,   76,   76,   70,   79,   81,   82,  494,   83,
       86,   82,   84,   83,   88,  493,   84,   89,   90,   88,
      105,  106,   91,  107,  108,  237,  109,  110,  106,  238,
      107,  111,  105,  109,  239,  196,   85,  197,  240,  105,
       85,   48,   92,   49,   48,   48,   48,   48,   48,   93,

       48,   48,   48,   48,   48,   48,   48,   48,   94,   48,
       48,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   48,   48,   48,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   48,   95,   96,   97,   49,   96,   96,   98,   96,
       96,   48,   99,   96,   96,  100,   96,   96,   96,   96,
      101,  102,   96,  103,  103,  103,  103,  103,  103,  103,
      103,  103,  103,   96,   96,   96,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,  103,  103,   96,  103,  113,  251,  113,  258,  259,

      252,  114,  115,  114,  115,  116,  492,  116,   48,   48,
       49,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,  117,  117,
      117,  117,  117,  117,  117,  117,  117,  117,   48,   48,
       48,  117,  117,  117,  117,  117,  117,  117,  117,  117,
      117,  117,  117,  117,  117,  117,  117,  117,   48,  117,
       48,  118,   49,   48,   48,   48,   48,   48,  119,  119,
       48,   48,  119,   48,   48,   48,   48,  120,   48,   48,
      121,  121,  121,  121,  121,  121,  121,  121,  121,  121,
       48,   48,   48,  121,  121,  121,  121,  121,  121,  121,

      121,  121,  121,  121,  121,  121,  121,  121,  121,  121,
       48,  121,   48,  122,  123,  289,  125,  200,  290,  126,
       48,  127,  123,  364,  125,  201,  255,  126,  202,  129,
      130,   48,  131,  132,  204,  133,  491,  134,  130,   48,
      131,  132,  490,  133,  135,  136,  137,  135,  138,  139,
      135,  140,  141,  135,  135,  135,  135,  135,  142,  143,
      143,  135,  144,  135,  145,  145,  146,  145,  145,  145,
      147,  148,  149,  145,  150,  135,  135,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  147,
      145,  145,  151,  145,  152,  145,  155,  155,  156,  155,

      157,  155,  155,  158,  159,  160,  155,  155,  155,  155,
      155,  155,  155,  155,  155,  155,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  159,  155,  160,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  159,  161,   49,   49,
      163,  163,  489,  164,  164,   49,   49,  167,  167,  242,
      168,  168,  171,  171,  172,  172,  243,  173,  173,  265,
      266,  215,  269,  266,  380,  244,  380,  165,  165,  201,
      276,  277,  202,  488,  169,  169,  299,  300,  217,  304,
      305,  174,  174,  175,  176,  177,  175,  175,  175,  175,

      175,  175,  175,  175,  175,  175,  178,  175,  175,  175,
      175,  175,  175,  179,  179,  179,  179,  179,  179,  179,
      179,  179,  179,  175,  175,  175,  179,  179,  179,  179,
      179,  179,  179,  180,  179,  179,  179,  179,  179,  179,
      179,  179,  179,  175,  179,  181,  182,  183,  181,  181,
      181,  181,  181,  181,  181,  184,  181,  185,  181,  181,
      181,  181,  181,  181,  181,  186,  186,  186,  186,  186,
      186,  186,  186,  186,  186,  181,  181,  181,  186,  186,
      186,  186,  186,  186,  186,  186,  186,  186,  186,  186,
      186,  186,  186,  186,  186,  181,  186,  187,  188,  189,

      187,  187,  187,  187,  187,  187,  187,  187,  187,  187,
      187,  187,  187,  187,  187,  187,  187,  190,  190,  190,
      190,  190,  190,  190,  190,  190,  190,  187,  187,  187,
      190,  190,  190,  190,  190,  190,  190,  190,  190,  190,
      190,  190,  190,  190,  190,  190,  190,  187,  190,  200,
      200,  200,  487,  209,  258,  259,  344,  201,  201,  201,
      202,  202,  202,  200,  215,  215,  204,  204,  204,  265,
      266,  201,  201,  201,  202,  202,  202,  269,  266,  311,
      204,  217,  217,  276,  277,  215,  206,  211,  212,  205,
      213,  312,  214,  201,  289,  207,  202,  290,  215,  345,

      219,  242,  217,  316,  208,  218,  201,  316,  243,  202,
      282,  284,  284,  284,  317,  217,  292,  244,  317,  311,
      289,  285,  285,  290,  320,  495,  409,  306,  237,  220,
      306,  312,  238,  239,  485,  292,  321,  240,  285,  221,
      222,  222,  292,  222,  289,  330,  222,  290,  222,  222,
      222,  222,  222,  201,  230,  230,  230,  222,  222,  222,
      314,  292,  204,  479,  251,  200,  200,  200,  252,  410,
      222,  222,  222,  201,  201,  201,  202,  202,  202,  378,
      378,  378,  204,  204,  204,  386,  300,  475,  200,  200,
      222,  230,  282,  283,  283,  284,  201,  201,  209,  202,

      202,  200,  200,  285,  285,  204,  204,  330,  286,  201,
      201,  311,  202,  202,  215,  388,  305,  311,  204,  204,
      285,  334,  201,  312,  204,  202,  335,  386,  300,  312,
      215,  217,  211,  212,  495,  213,  306,  214,  201,  306,
      215,  202,  215,  336,  215,  337,  470,  217,  201,  316,
      201,  202,  201,  202,  215,  202,  215,  217,  215,  217,
      317,  217,  201,  472,  201,  202,  201,  202,  409,  202,
      339,  217,  215,  217,  467,  217,  340,  388,  305,  215,
      201,  311,  320,  202,  215,  342,  341,  201,  320,  217,
      202,  346,  201,  312,  321,  202,  217,  495,  461,  200,

      321,  217,  282,  283,  283,  284,  311,  201,  311,  347,
      202,  410,  436,  285,  379,  200,  204,  434,  312,  263,
      312,  348,  419,  201,  393,  457,  202,  349,  222,  222,
      379,  222,  204,  434,  222,  452,  222,  222,  222,  222,
      222,  411,  230,  230,  230,  222,  222,  222,  444,  320,
      442,  395,  282,  284,  284,  284,  394,  200,  222,  222,
      222,  321,  391,  285,  285,  201,  458,  440,  202,  459,
      459,  459,  439,  402,  204,  200,  438,  200,  222,  230,
      285,  201,  470,  201,  202,  201,  202,  215,  202,  215,
      204,  437,  204,  311,  204,  201,  320,  201,  202,  472,

      202,  215,  401,  215,  217,  312,  217,  436,  321,  201,
      470,  201,  202,  215,  202,  215,  403,  413,  217,  404,
      217,  201,  405,  201,  202,  201,  202,  472,  202,  215,
      217,  215,  217,  200,  217,  435,  431,  201,  406,  201,
      202,  201,  202,  430,  202,  407,  217,  481,  217,  429,
      204,  378,  378,  378,  200,  402,  408,  428,  432,  371,
      412,  433,  201,  201,  483,  202,  202,  446,  200,  215,
      414,  204,  204,  415,  432,  201,  201,  201,  202,  202,
      202,  449,  371,  215,  204,  204,  217,  426,  425,  201,
      311,  201,  202,  215,  202,  459,  459,  459,  217,  445,

      217,  201,  312,  484,  202,  215,  484,  263,  481,  413,
      217,  311,  447,  201,  448,  312,  202,  201,  312,  454,
      202,  215,  217,  312,  450,  483,  217,  201,  423,  201,
      202,  462,  202,  422,  460,  451,  217,  360,  217,  201,
      360,  446,  202,  200,  481,  215,  421,  420,  204,  201,
      453,  201,  202,  201,  202,  449,  202,  474,  204,  465,
      204,  483,  217,  201,  418,  455,  202,  201,  417,  215,
      202,  468,  217,  416,  411,  331,  217,  201,  399,  201,
      202,  398,  202,  454,  215,  397,  217,  395,  217,  463,
      464,  201,  201,  319,  202,  202,  459,  459,  459,  462,

      217,  217,  394,  476,  477,  315,  433,  201,  391,  310,
      202,  201,  201,  466,  202,  202,  204,  465,  215,  390,
      204,  217,  389,  307,  387,  201,  201,  385,  202,  202,
      469,  468,  480,  476,  217,  217,  384,  383,  382,  201,
      201,  201,  202,  202,  202,  477,  486,  381,  217,  217,
      204,  377,  376,  201,  201,  278,  202,  202,  480,  486,
      375,  373,  217,  217,  478,  371,  201,  201,  370,  202,
      202,  369,  368,  263,  262,  217,  217,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   80,   80,   80,   80,   80,   80,   80,   80,   80,

       80,   80,   80,   80,   80,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  124,  124,  124,
      124,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      124,  128,  128,  128,  128,  128,  128,  128,  128,  128,
      128,  128,  128,  128,  128,  153,  153,  153,  153,  153,
      153,  153,  153,  153,  153,  153,  153,  153,  153,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,

      162,  162,  162,  166,  166,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  166,  166,  166,  170,  170,  170,
      170,  170,  170,  170,  170,  170,  170,  170,  170,  170,
      170,  192,  365,  362,  360,  359,  248,  246,  241,  241,
      192,  192,  235,  192,  195,  195,  357,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  203,  356,
      355,  354,  203,  203,  353,  203,  203,  203,  203,  350,
      203,  210,  331,  329,  328,  324,  193,  191,  319,  315,
      210,  210,  310,  210,  216,  309,  308,  307,  216,  216,
      307,  216,  216,  216,  216,  302,  216,  222,  222,  297,

      294,  293,  222,  222,  291,  222,  222,  288,  281,  222,
      222,  224,  224,  279,  224,  224,  224,  224,  224,  224,
      224,  224,  224,  224,  224,  227,  278,  227,  227,  275,
      227,  231,  273,  271,  268,  231,  231,  231,  231,  231,
      231,  231,  231,  267,  231,  234,  234,  263,  234,  234,
      234,  234,  234,  234,  234,  234,  234,  234,  234,  236,
      236,  262,  236,  256,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  245,  257,  245,  245,  256,  245,  247,
      247,  254,  247,  248,  247,  247,  247,  247,  247,  247,
      247,  247,  247,  249,  246,  249,  249,  241,  249,  250,

      235,  233,  232,  229,  250,  250,  228,  250,  250,  250,
      250,  250,  250,  253,  226,  225,  253,  223,  199,  198,
      194,  193,  253,  253,  191,  253,  255,  255,  495,  255,
      255,  255,  255,  255,  255,  255,  255,  255,  255,  255,
      260,  260,  154,  260,  260,  260,  260,  260,  260,  260,
      260,  260,  260,  260,  261,  154,  261,  261,   49,  261,
      264,  264,   49,  264,  264,   49,  264,  270,   49,  495,
      495,  495,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  272,  495,  495,  495,  495,  495,  272,  272,  495,
      272,  274,  274,  495,  274,  495,  274,  274,  274,  274,

      274,  274,  274,  274,  274,  280,  280,  495,  280,  280,
      280,  280,  280,  280,  280,  280,  280,  280,  280,  287,
      495,  287,  287,  495,  287,  295,  495,  295,  295,  495,
      295,  296,  296,  495,  495,  296,  296,  296,  296,  296,
      296,  296,  296,  495,  296,  298,  298,  298,  298,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  298,  301,
      301,  495,  495,  301,  301,  301,  301,  301,  301,  301,
      301,  495,  301,  303,  303,  303,  303,  303,  303,  303,
      303,  303,  303,  303,  303,  303,  303,  306,  306,  306,
      495,  306,  306,  306,  306,  306,  306,  306,  306,  306,

      306,  313,  495,  495,  495,  495,  495,  313,  313,  495,
      313,  313,  495,  313,  318,  495,  495,  495,  495,  318,
      495,  318,  495,  318,  318,  495,  318,  322,  495,  495,
      495,  495,  495,  322,  322,  495,  322,  322,  495,  322,
      323,  495,  495,  495,  323,  323,  495,  323,  323,  323,
      323,  495,  323,  325,  325,  495,  325,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  326,  326,  495,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  327,  327,  327,  327,  495,  327,  327,  327,  327,
      327,  327,  327,  327,  327,  332,  495,  495,  495,  495,

      495,  495,  495,  495,  332,  332,  495,  332,  203,  495,
      495,  495,  203,  203,  495,  203,  203,  203,  203,  495,
      203,  333,  333,  333,  333,  333,  333,  333,  333,  333,
      495,  333,  333,  333,  333,  210,  495,  495,  495,  495,
      495,  495,  495,  495,  210,  210,  495,  210,  338,  495,
      495,  495,  338,  338,  495,  338,  338,  338,  338,  495,
      338,  216,  495,  495,  495,  216,  216,  495,  216,  216,
      216,  216,  495,  216,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  495,  343,  343,  343,  343,  222,  222,
      495,  495,  495,  222,  222,  495,  222,  222,  495,  495,

      222,  222,  351,  351,  495,  351,  351,  351,  351,  351,
      351,  351,  351,  351,  351,  351,  352,  352,  352,  352,
      495,  352,  352,  352,  352,  352,  352,  352,  352,  352,
      227,  495,  227,  227,  495,  227,  231,  495,  495,  495,
      231,  231,  231,  231,  231,  231,  231,  231,  495,  231,
      236,  236,  495,  236,  495,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  245,  495,  245,  245,  495,  245,
      358,  358,  495,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  249,  495,  249,  249,  495,  249,
      250,  495,  495,  495,  495,  250,  250,  495,  250,  250,

      250,  250,  250,  250,  253,  495,  495,  253,  495,  495,
      495,  495,  495,  253,  253,  495,  253,  361,  495,  495,
      495,  495,  495,  495,  361,  495,  361,  361,  495,  361,
      255,  255,  495,  255,  255,  255,  255,  255,  255,  255,
      255,  255,  255,  255,  363,  363,  363,  363,  363,  363,
      363,  363,  363,  363,  363,  363,  363,  363,  366,  366,
      495,  366,  366,  366,  366,  366,  366,  366,  366,  366,
      366,  366,  261,  495,  261,  261,  495,  261,  367,  367,
      495,  367,  264,  264,  495,  264,  264,  495,  264,  270,
      495,  495,  495,  495,  270,  270,  270,  270,  270,  270,

      270,  270,  270,  372,  495,  495,  495,  495,  495,  495,
      372,  495,  372,  372,  495,  372,  374,  374,  495,  374,
      374,  374,  374,  374,  374,  374,  374,  374,  374,  374,
      280,  280,  495,  280,  280,  280,  280,  280,  280,  280,
      280,  280,  280,  280,  287,  495,  287,  287,  495,  287,
      295,  495,  295,  295,  495,  295,  296,  296,  495,  495,
      296,  296,  296,  296,  296,  296,  296,  296,  495,  296,
      301,  301,  495,  495,  301,  301,  301,  301,  301,  301,
      301,  301,  495,  301,  306,  306,  306,  495,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  392,  495,

      495,  495,  495,  495,  495,  495,  495,  392,  392,  495,
      392,  313,  495,  495,  495,  495,  495,  313,  313,  495,
      313,  313,  495,  313,  318,  495,  495,  495,  495,  318,
      495,  318,  495,  318,  318,  495,  318,  396,  495,  495,
      495,  495,  495,  495,  495,  495,  396,  396,  495,  396,
      322,  495,  495,  495,  495,  495,  322,  322,  495,  322,
      322,  495,  322,  323,  495,  495,  495,  323,  323,  495,
      323,  323,  323,  323,  495,  323,  325,  325,  495,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  325,
      326,  326,  495,  326,  326,  326,  326,  326,  326,  326,

      326,  326,  326,  326,  332,  495,  495,  495,  495,  495,
      495,  495,  495,  332,  332,  495,  332,  400,  495,  495,
      495,  400,  400,  495,  400,  400,  400,  400,  495,  400,
      203,  495,  495,  495,  203,  203,  495,  203,  203,  203,
      203,  495,  203,  338,  495,  495,  495,  338,  338,  495,
      338,  338,  338,  338,  495,  338,  216,  495,  495,  495,
      216,  216,  495,  216,  216,  216,  216,  495,  216,  351,
      351,  495,  351,  351,  351,  351,  351,  351,  351,  351,
      351,  351,  351,  227,  227,  495,  227,  227,  495,  227,
      424,  424,  495,  424,  424,  495,  424,  427,  427,  427,

      427,  495,  427,  427,  427,  427,  427,  427,  427,  427,
      427,  441,  495,  495,  495,  495,  495,  441,  441,  495,
      441,  441,  495,  441,  443,  495,  495,  495,  495,  495,
      443,  443,  495,  443,  443,  495,  443,  456,  456,  495,
      456,  471,  495,  495,  495,  495,  495,  495,  471,  471,
      471,  471,  495,  471,  473,  473,  495,  473,  482,  495,
      495,  495,  495,  495,  495,  482,  482,  482,  482,  495,
      482,   47,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,

      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495
    } ;

static yyconst flex_int16_t yy_chk[2725] =
    {   0,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,

        4,    4,    4,    4,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    9,    9,  493,    9,
       10,   10,    9,   10,   11,  492,   10,   11,   12,   12,
       17,   17,   12,   17,   17,   88,   17,   18,   18,   88,
       18,   18,   17,   18,   90,   54,    9,   54,   90,   18,
       10,   13,   13,   13,   13,   13,   13,   13,   13,   13,

       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   19,  106,   20,  110,  110,

      106,   19,   19,   20,   20,   19,  490,   20,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,

       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   25,   25,   25,  147,   25,   59,  147,   25,
       26,   26,   26,  256,   26,   59,  256,   26,   59,   27,
       27,   25,   27,   27,   59,   27,  489,   28,   28,   26,
       28,   28,  488,   28,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   33,   33,   33,   33,

       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   35,   36,
       35,   36,  487,   35,   36,   37,   38,   37,   38,   92,
       37,   38,   39,   40,   39,   40,   92,   39,   40,  122,
      122,   65,  127,  127,  574,   92,  574,   35,   36,   65,
      134,  134,   65,  485,   37,   38,  165,  165,   65,  169,
      169,   39,   40,   41,   41,   41,   41,   41,   41,   41,

       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   45,   45,   45,

       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   60,
       61,   62,  479,   64,  258,  258,  217,   60,   61,   62,
       60,   61,   62,   63,   67,   66,   60,   61,   62,  265,
      265,   63,   67,   66,   63,   67,   66,  269,  269,  179,
       63,   67,   66,  276,  276,   68,   61,   64,   64,   60,
       64,  179,   64,   68,  149,   62,   68,  149,   69,  217,

       67,  242,   68,  186,   63,   66,   69,  316,  242,   69,
      143,  143,  143,  143,  186,   69,  149,  242,  316,  180,
      151,  143,  143,  151,  190,  174,  344,  174,  237,   68,
      174,  180,  237,  239,  475,  149,  190,  239,  143,   69,
       79,   79,  151,   79,  292,  201,   79,  292,   79,   79,
       79,   79,   79,  201,   79,   79,   79,   79,   79,   79,
      180,  151,  201,  467,  251,  192,  200,  203,  251,  344,
       79,   79,   79,  192,  200,  203,  192,  200,  203,  282,
      282,  282,  192,  200,  203,  299,  299,  461,  205,  206,
       79,   79,  142,  142,  142,  142,  205,  206,  209,  205,

      206,  207,  208,  142,  142,  205,  206,  330,  142,  207,
      208,  311,  207,  208,  210,  304,  304,  313,  207,  208,
      142,  205,  210,  311,  330,  210,  206,  386,  386,  313,
      211,  210,  209,  209,  307,  209,  307,  209,  211,  307,
      212,  211,  213,  207,  214,  208,  456,  211,  212,  318,
      213,  212,  214,  213,  215,  214,  216,  212,  218,  213,
      318,  214,  215,  456,  216,  215,  218,  216,  409,  218,
      211,  215,  219,  216,  452,  218,  212,  388,  388,  220,
      219,  314,  320,  219,  221,  214,  213,  220,  322,  219,
      220,  218,  221,  314,  320,  221,  220,  355,  444,  323,

      322,  221,  283,  283,  283,  283,  392,  323,  393,  219,
      323,  409,  435,  283,  283,  332,  323,  380,  392,  424,
      393,  220,  355,  332,  314,  419,  332,  221,  230,  230,
      283,  230,  332,  380,  230,  411,  230,  230,  230,  230,
      230,  410,  230,  230,  230,  230,  230,  230,  399,  396,
      393,  395,  284,  284,  284,  284,  394,  334,  230,  230,
      230,  396,  391,  284,  284,  334,  432,  390,  334,  432,
      432,  432,  389,  335,  334,  336,  384,  337,  230,  230,
      284,  335,  470,  336,  335,  337,  336,  338,  337,  339,
      335,  383,  336,  441,  337,  338,  443,  339,  338,  470,

      339,  340,  334,  341,  338,  441,  339,  382,  443,  340,
      471,  341,  340,  342,  341,  346,  336,  347,  340,  337,
      341,  342,  339,  346,  342,  347,  346,  471,  347,  348,
      342,  349,  346,  400,  347,  381,  377,  348,  340,  349,
      348,  400,  349,  376,  400,  341,  348,  473,  349,  375,
      400,  378,  378,  378,  401,  402,  342,  373,  378,  372,
      346,  378,  401,  402,  473,  401,  402,  403,  404,  405,
      348,  401,  402,  349,  378,  403,  404,  405,  403,  404,
      405,  406,  371,  407,  403,  404,  405,  369,  368,  406,
      442,  407,  406,  408,  407,  458,  458,  458,  406,  401,

      407,  408,  442,  474,  408,  412,  484,  367,  481,  413,
      408,  460,  404,  412,  405,  474,  412,  413,  484,  414,
      413,  415,  412,  460,  407,  481,  413,  414,  365,  415,
      414,  445,  415,  362,  442,  408,  414,  361,  415,  445,
      360,  446,  445,  447,  482,  448,  357,  356,  445,  446,
      412,  447,  446,  448,  447,  449,  448,  460,  446,  450,
      447,  482,  448,  449,  354,  415,  449,  450,  353,  451,
      450,  453,  449,  350,  345,  331,  450,  451,  329,  453,
      451,  328,  453,  454,  455,  324,  451,  321,  453,  447,
      448,  454,  455,  319,  454,  455,  459,  459,  459,  462,

      454,  455,  317,  463,  464,  315,  459,  462,  312,  310,
      462,  463,  464,  451,  463,  464,  462,  465,  466,  309,
      463,  464,  308,  306,  302,  465,  466,  297,  465,  466,
      455,  468,  469,  476,  465,  466,  294,  293,  291,  468,
      469,  476,  468,  469,  476,  477,  478,  288,  468,  469,
      476,  281,  279,  477,  478,  278,  477,  478,  480,  486,
      275,  273,  477,  478,  466,  272,  480,  486,  271,  480,
      486,  268,  267,  264,  262,  480,  486,  496,  496,  496,
      496,  496,  496,  496,  496,  496,  496,  496,  496,  496,
      496,  497,  497,  497,  497,  497,  497,  497,  497,  497,

      497,  497,  497,  497,  497,  498,  498,  498,  498,  498,
      498,  498,  498,  498,  498,  498,  498,  498,  498,  499,
      499,  499,  499,  499,  499,  499,  499,  499,  499,  499,
      499,  499,  499,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  503,  503,  503,  503,  503,  504,
      504,  504,  504,  504,  504,  504,  504,  504,  504,  504,

      504,  504,  504,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  506,  506,  506,
      506,  506,  506,  506,  506,  506,  506,  506,  506,  506,
      506,  507,  257,  254,  253,  252,  248,  246,  241,  240,
      507,  507,  235,  507,  508,  508,  233,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  509,  232,
      229,  228,  509,  509,  226,  509,  509,  509,  509,  223,
      509,  510,  202,  199,  198,  194,  193,  191,  188,  182,
      510,  510,  176,  510,  511,  173,  172,  171,  511,  511,
      170,  511,  511,  511,  511,  168,  511,  512,  512,  163,

      158,  157,  512,  512,  148,  512,  512,  146,  140,  512,
      512,  513,  513,  138,  513,  513,  513,  513,  513,  513,
      513,  513,  513,  513,  513,  514,  136,  514,  514,  133,
      514,  515,  131,  130,  126,  515,  515,  515,  515,  515,
      515,  515,  515,  125,  515,  516,  516,  121,  516,  516,
      516,  516,  516,  516,  516,  516,  516,  516,  516,  517,
      517,  118,  517,  111,  517,  517,  517,  517,  517,  517,
      517,  517,  517,  518,  109,  518,  518,  108,  518,  519,
      519,  107,  519,  101,  519,  519,  519,  519,  519,  519,
      519,  519,  519,  520,   97,  520,  520,   91,  520,  521,

       86,   84,   83,   78,  521,  521,   77,  521,  521,  521,
      521,  521,  521,  522,   74,   73,  522,   72,   58,   55,
       53,   52,  522,  522,   51,  522,  523,  523,   47,  523,
      523,  523,  523,  523,  523,  523,  523,  523,  523,  523,
      524,  524,   32,  524,  524,  524,  524,  524,  524,  524,
      524,  524,  524,  524,  525,   31,  525,  525,    8,  525,
      526,  526,    7,  526,  526,    2,  526,  527,    1,    0,
        0,    0,  527,  527,  527,  527,  527,  527,  527,  527,
      527,  528,    0,    0,    0,    0,    0,  528,  528,    0,
      528,  529,  529,    0,  529,    0,  529,  529,  529,  529,

      529,  529,  529,  529,  529,  530,  530,    0,  530,  530,
      530,  530,  530,  530,  530,  530,  530,  530,  530,  531,
        0,  531,  531,    0,  531,  532,    0,  532,  532,    0,
      532,  533,  533,    0,    0,  533,  533,  533,  533,  533,
      533,  533,  533,    0,  533,  534,  534,  534,  534,  534,
      534,  534,  534,  534,  534,  534,  534,  534,  534,  535,
      535,    0,    0,  535,  535,  535,  535,  535,  535,  535,
      535,    0,  535,  536,  536,  536,  536,  536,  536,  536,
      536,  536,  536,  536,  536,  536,  536,  537,  537,  537,
        0,  537,  537,  537,  537,  537,  537,  537,  537,  537,

      537,  538,    0,    0,    0,    0,    0,  538,  538,    0,
      538,  538,    0,  538,  539,    0,    0,    0,    0,  539,
        0,  539,    0,  539,  539,    0,  539,  540,    0,    0,
        0,    0,    0,  540,  540,    0,  540,  540,    0,  540,
      541,    0,    0,    0,  541,  541,    0,  541,  541,  541,
      541,    0,  541,  542,  542,    0,  542,  542,  542,  542,
      542,  542,  542,  542,  542,  542,  542,  543,  543,    0,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  544,  544,  544,  544,    0,  544,  544,  544,  544,
      544,  544,  544,  544,  544,  545,    0,    0,    0,    0,

        0,    0,    0,    0,  545,  545,    0,  545,  546,    0,
        0,    0,  546,  546,    0,  546,  546,  546,  546,    0,
      546,  547,  547,  547,  547,  547,  547,  547,  547,  547,
        0,  547,  547,  547,  547,  548,    0,    0,    0,    0,
        0,    0,    0,    0,  548,  548,    0,  548,  549,    0,
        0,    0,  549,  549,    0,  549,  549,  549,  549,    0,
      549,  550,    0,    0,    0,  550,  550,    0,  550,  550,
      550,  550,    0,  550,  551,  551,  551,  551,  551,  551,
      551,  551,  551,    0,  551,  551,  551,  551,  552,  552,
        0,    0,    0,  552,  552,    0,  552,  552,    0,    0,

      552,  552,  553,  553,    0,  553,  553,  553,  553,  553,
      553,  553,  553,  553,  553,  553,  554,  554,  554,  554,
        0,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      555,    0,  555,  555,    0,  555,  556,    0,    0,    0,
      556,  556,  556,  556,  556,  556,  556,  556,    0,  556,
      557,  557,    0,  557,    0,  557,  557,  557,  557,  557,
      557,  557,  557,  557,  558,    0,  558,  558,    0,  558,
      559,  559,    0,  559,  559,  559,  559,  559,  559,  559,
      559,  559,  559,  559,  560,    0,  560,  560,    0,  560,
      561,    0,    0,    0,    0,  561,  561,    0,  561,  561,

      561,  561,  561,  561,  562,    0,    0,  562,    0,    0,
        0,    0,    0,  562,  562,    0,  562,  563,    0,    0,
        0,    0,    0,    0,  563,    0,  563,  563,    0,  563,
      564,  564,    0,  564,  564,  564,  564,  564,  564,  564,
      564,  564,  564,  564,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  566,  566,
        0,  566,  566,  566,  566,  566,  566,  566,  566,  566,
      566,  566,  567,    0,  567,  567,    0,  567,  568,  568,
        0,  568,  569,  569,    0,  569,  569,    0,  569,  570,
        0,    0,    0,    0,  570,  570,  570,  570,  570,  570,

      570,  570,  570,  571,    0,    0,    0,    0,    0,    0,
      571,    0,  571,  571,    0,  571,  572,  572,    0,  572,
      572,  572,  572,  572,  572,  572,  572,  572,  572,  572,
      573,  573,    0,  573,  573,  573,  573,  573,  573,  573,
      573,  573,  573,  573,  575,    0,  575,  575,    0,  575,
      576,    0,  576,  576,    0,  576,  577,  577,    0,    0,
      577,  577,  577,  577,  577,  577,  577,  577,    0,  577,
      578,  578,    0,    0,  578,  578,  578,  578,  578,  578,
      578,  578,    0,  578,  579,  579,  579,    0,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  580,    0,

        0,    0,    0,    0,    0,    0,    0,  580,  580,    0,
      580,  581,    0,    0,    0,    0,    0,  581,  581,    0,
      581,  581,    0,  581,  582,    0,    0,    0,    0,  582,
        0,  582,    0,  582,  582,    0,  582,  583,    0,    0,
        0,    0,    0,    0,    0,    0,  583,  583,    0,  583,
      584,    0,    0,    0,    0,    0,  584,  584,    0,  584,
      584,    0,  584,  585,    0,    0,    0,  585,  585,    0,
      585,  585,  585,  585,    0,  585,  586,  586,    0,  586,
      586,  586,  586,  586,  586,  586,  586,  586,  586,  586,
      587,  587,    0,  587,  587,  587,  587,  587,  587,  587,

      587,  587,  587,  587,  588,    0,    0,    0,    0,    0,
        0,    0,    0,  588,  588,    0,  588,  589,    0,    0,
        0,  589,  589,    0,  589,  589,  589,  589,    0,  589,
      590,    0,    0,    0,  590,  590,    0,  590,  590,  590,
      590,    0,  590,  591,    0,    0,    0,  591,  591,    0,
      591,  591,  591,  591,    0,  591,  592,    0,    0,    0,
      592,  592,    0,  592,  592,  592,  592,    0,  592,  593,
      593,    0,  593,  593,  593,  593,  593,  593,  593,  593,
      593,  593,  593,  594,  594,    0,  594,  594,    0,  594,
      595,  595,    0,  595,  595,    0,  595,  596,  596,  596,

      596,    0,  596,  596,  596,  596,  596,  596,  596,  596,
      596,  597,    0,    0,    0,    0,    0,  597,  597,    0,
      597,  597,    0,  597,  598,    0,    0,    0,    0,    0,
      598,  598,    0,  598,  598,    0,  598,  599,  599,    0,
      599,  600,    0,    0,    0,    0,    0,    0,  600,  600,
      600,  600,    0,  600,  601,  601,    0,  601,  602,    0,
        0,    0,    0,    0,    0,  602,  602,  602,  602,    0,
      602,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,

      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495
    } ;

extern int pyscannerYY_flex_debug;
int pyscannerYY_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *pyscannerYYtext;
#line 1 "pyscanner.l"
/******************************************************************************
 *
 * 
 *
 * Copyright (C) 1997-2015 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby 
 * granted. No representations are made about the suitability of this software 
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 * Documents produced by Doxygen are derivative works derived from the
 * input used in their production; they are not affected by this license.
 *
 */
/*  This code is based on the work done by the MoxyPyDoxy team
 *  (Linda Leong, Mike Rivera, Kim Truong, and Gabriel Estrada)
 *  in Spring 2005 as part of CS 179E: Compiler Design Project
 *  at the University of California, Riverside; the course was
 *  taught by Peter H. Froehlich <phf@acm.org>.
 */
#line 26 "pyscanner.l"

/*
 *	includes
 */
#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <ctype.h>

#include <qarray.h>
#include <qstack.h>
#include <qregexp.h>
#include <qfile.h>
#include <qfileinfo.h>
  
#include "pyscanner.h"
#include "entry.h"
#include "message.h"
#include "config.h"
#include "doxygen.h"
#include "util.h"
#include "defargs.h"
#include "language.h"
#include "commentscan.h"
#include "pycode.h"
#include "arguments.h"

// Toggle for some debugging info
//#define DBG_CTX(x) fprintf x
#define DBG_CTX(x) do { } while(0)

#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1

/* -----------------------------------------------------------------
 *
 *	statics
 */

  
static ParserInterface *g_thisParser;
static const char *     inputString;
static int		inputPosition;
static QFile            inputFile;

static Protection	protection;

static Entry*		current_root = 0 ;
static Entry*		current      = 0 ;
static Entry*		previous     = 0 ;
static Entry*		bodyEntry    = 0 ;
static int		yyLineNr     = 1 ;
static QCString		yyFileName;
static MethodTypes 	mtype;
static bool    		gstat;
static Specifier 	virt;

static int              docBlockContext;
static QCString         docBlock;
static bool             docBlockInBody;
static bool             docBlockJavaStyle;
static bool             docBrief;
static bool             docBlockSpecial;

static bool             g_doubleQuote;
static bool             g_specialBlock;
static int              g_stringContext;
static QGString *       g_copyString;
static int              g_indent = 0;
static int              g_curIndent = 0;

static QDict<QCString>  g_packageNameCache(257);

static char             g_atomStart;
static char             g_atomEnd;
static int              g_atomCount;

//static bool             g_insideConstructor;

static QCString         g_moduleScope;
static QCString         g_packageName;

//static bool             g_hideClassDocs;

static QCString         g_defVal;
static int              g_braceCount;

static bool             g_lexInit = FALSE;
static bool             g_packageCommentAllowed;

static bool             g_start_init = FALSE;
static int              g_search_count = 0;

//-----------------------------------------------------------------------------


static void initParser()
{
  protection = Public;
  mtype = Method;
  gstat = FALSE;
  virt = Normal;
  previous = 0;
  g_packageCommentAllowed = TRUE;
  g_packageNameCache.setAutoDelete(TRUE);
}

static void initEntry()
{
  //current->python = TRUE;
  current->protection = protection ;
  current->mtype      = mtype;
  current->virt       = virt;
  current->stat       = gstat;
  current->lang       = SrcLangExt_Python; 
  current->setParent(current_root);
  initGroupInfo(current);
  gstat = FALSE;
}

static void newEntry()
{
  previous = current;
  current_root->addSubEntry(current);
  current = new Entry ;
  initEntry();
}

static void newVariable()
{
  if (!current->name.isEmpty() && current->name.at(0)=='_') // mark as private
  {
    current->protection=Private;
  }
  if (current_root->section&Entry::COMPOUND_MASK) // mark as class variable
  {
    current->stat = TRUE;
  }
  newEntry();
}

static void newFunction()
{
  if (current->name.left(2)=="__" && current->name.right(2)=="__")
  {
    // special method name, see
    // http://docs.python.org/ref/specialnames.html
    current->protection=Public;
  }
  else if (current->name.at(0)=='_')
  {
    current->protection=Private;
  }
}

static inline int computeIndent(const char *s)
{
  int col=0;
  static int tabSize=Config_getInt("TAB_SIZE");
  const char *p=s;
  char c;
  while ((c=*p++))
  {
    if (c==' ') col++;
    else if (c=='\t') col+=tabSize-(col%tabSize);
    else break;
  }
  return col;
}

static QCString findPackageScopeFromPath(const QCString &path)
{
  QCString *pScope = g_packageNameCache.find(path);
  if (pScope)
  {
    return *pScope;
  }
  QFileInfo pf(path+"/__init__.py"); // found package initialization file
  if (pf.exists())
  {
    int i=path.findRev('/');
    if (i!=-1)
    {
      QCString scope = findPackageScopeFromPath(path.left(i));
      if (!scope.isEmpty())
      {
	scope+="::";
      }
      scope+=path.mid(i+1);
      g_packageNameCache.insert(path,new QCString(scope));
      return scope;
    }
  }
  return "";
}
  
static QCString findPackageScope(const char *fileName)
{
  if (fileName==0) return "";
  QFileInfo fi(fileName);
  return findPackageScopeFromPath(fi.dirPath(TRUE).data());
}

//-----------------------------------------------------------------------------

static void lineCount()
{
  DBG_CTX((stderr,"yyLineNr=%d\n",yyLineNr));
  for (const char *p = pyscannerYYtext; *p; ++p)
  {
    yyLineNr += (*p == '\n') ;
  }
}

static void incLineNr()
{
  DBG_CTX((stderr,"yyLineNr=%d\n",yyLineNr));
  yyLineNr++;
}

#if 0
// Appends the current-name to current-type;
// Destroys current-name.
// Destroys current->args and current->argList
static void addType( Entry* current )
{
    uint tl=current->type.length();
    if ( tl>0 && !current->name.isEmpty() && current->type.at(tl-1)!='.') 
    {
      current->type += ' ' ;
    }
    current->type += current->name ;
    current->name.resize(0) ;
    tl=current->type.length();
    if ( tl>0 && !current->args.isEmpty() && current->type.at(tl-1)!='.') 
    {
      current->type += ' ' ;
    }
    current->type += current->args ;
    current->args.resize(0) ;
    current->argList->clear();
}

static QCString stripQuotes(const char *s)
{
  QCString name;
  if (s==0 || *s==0) return name;
  name=s;
  if (name.at(0)=='"' && name.at(name.length()-1)=='"')
  {
    name=name.mid(1,name.length()-2);
  }
  return name;
}
#endif
//-----------------------------------------------------------------

//-----------------------------------------------------------------
static void startCommentBlock(bool brief)
{
  if (brief)
  {
    current->briefFile = yyFileName;
    current->briefLine = yyLineNr;
  }
  else
  {
    current->docFile = yyFileName;
    current->docLine = yyLineNr;
  }
}

/*
static void appendDocBlock() {
  previous = current;
  current_root->addSubEntry(current);
  current = new Entry;
  initEntry();
}
*/

static void handleCommentBlock(const QCString &doc,bool brief)
{
  //printf("handleCommentBlock(doc=[%s] brief=%d docBlockInBody=%d docBlockJavaStyle=%d\n",
  //    doc.data(),brief,docBlockInBody,docBlockJavaStyle);

  // TODO: Fix me
  docBlockInBody=FALSE;
  
  if (docBlockInBody && previous && !previous->doc.isEmpty())
  {
    previous->doc=previous->doc.stripWhiteSpace()+"\n\n";
  }

  int position = 0;
  bool needsEntry;
  int lineNr = brief ? current->briefLine : current->docLine;
  while (parseCommentBlock(
	g_thisParser,
	(docBlockInBody && previous) ? previous : current,
	doc,     // text
	yyFileName, // file
	lineNr,
	docBlockInBody ? FALSE : brief, 
    docBlockJavaStyle, // javadoc style // or FALSE,
	docBlockInBody,
	protection,
        position,
        needsEntry)
     ) // need to start a new entry
  {
    if (needsEntry)
    {
      newEntry();
    }
  }
  if (needsEntry)
  {
    newEntry();
  }

}

static void endOfDef(int correction=0)
{
  //printf("endOfDef at=%d\n",yyLineNr);
  if (bodyEntry)
  {
    bodyEntry->endBodyLine  = yyLineNr-correction;
    bodyEntry = 0;
  }
  newEntry();
  //g_insideConstructor = FALSE;
}

static inline void addToString(const char *s)
{
  if (g_copyString) (*g_copyString)+=s;
}

static void initTriDoubleQuoteBlock()
{
  docBlockContext   = YY_START;
  docBlockInBody    = FALSE;
  docBlockJavaStyle = TRUE;
  docBlockSpecial   = pyscannerYYtext[3]=='!';
  docBlock.resize(0);
  g_doubleQuote = TRUE;
  startCommentBlock(FALSE);
}

static void initTriSingleQuoteBlock()
{
  docBlockContext   = YY_START;
  docBlockInBody    = FALSE;
  docBlockJavaStyle = TRUE;
  docBlockSpecial   = pyscannerYYtext[3]=='!';
  docBlock.resize(0);
  g_doubleQuote = FALSE;
  startCommentBlock(FALSE);
}

static void initSpecialBlock()
{
  docBlockContext   = YY_START;
  docBlockInBody    = FALSE;
  docBlockJavaStyle = TRUE;
  docBrief = TRUE;
  docBlock.resize(0);
  startCommentBlock(TRUE);
}

static void searchFoundDef()
{
  current->fileName  = yyFileName;
  current->startLine = yyLineNr;
  current->bodyLine  = yyLineNr;
  current->section = Entry::FUNCTION_SEC;
  current->lang = SrcLangExt_Python;
  current->virt = Normal;
  current->stat = gstat;
  current->mtype = mtype = Method;
  current->type.resize(0);
  current->name.resize(0);
  current->args.resize(0);
  current->argList->clear();
  g_packageCommentAllowed = FALSE;
  gstat=FALSE;
  //printf("searchFoundDef at=%d\n",yyLineNr);
}

static void searchFoundClass()
{
  current->section = Entry::CLASS_SEC;
  current->argList->clear();
  current->type += "class" ;
  current->fileName  = yyFileName;
  current->startLine  = yyLineNr;
  current->bodyLine  = yyLineNr;
  g_packageCommentAllowed = FALSE;
}

//-----------------------------------------------------------------------------
/* ----------------------------------------------------------------- */
#undef	YY_INPUT
#define	YY_INPUT(buf,result,max_size) result=yyread(buf,max_size);

static int yyread(char *buf,int max_size)
{
  int c=0;
  while ( c < max_size && inputString[inputPosition] )
  {
    *buf = inputString[inputPosition++] ;
    //printf("%d (%c)\n",*buf,*buf);
    c++; buf++;
  }
  return c;
}

/* start command character */
/* Main start state */


/* Mid-comment states */
/* %x FuncDoubleComment */
/* %x ClassDoubleComment */



/* Function states */




/* Class states */




/* Variable states */



/* String states */



/* import */



#line 1849 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pyscanner.cpp"

#define INITIAL 0
#define Search 1
#define SearchMemVars 2
#define TryClassDocString 3
#define TripleComment 4
#define SpecialComment 5
#define FunctionDec 6
#define FunctionParams 7
#define FunctionBody 8
#define FunctionParamDefVal 9
#define ClassDec 10
#define ClassInheritance 11
#define ClassCaptureIndent 12
#define ClassBody 13
#define VariableDec 14
#define VariableEnd 15
#define VariableAtom 16
#define SingleQuoteString 17
#define DoubleQuoteString 18
#define TripleString 19
#define FromMod 20
#define FromModItem 21
#define Import 22

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int pyscannerYYlex_destroy (void );

int pyscannerYYget_debug (void );

void pyscannerYYset_debug (int debug_flag  );

YY_EXTRA_TYPE pyscannerYYget_extra (void );

void pyscannerYYset_extra (YY_EXTRA_TYPE user_defined  );

FILE *pyscannerYYget_in (void );

void pyscannerYYset_in  (FILE * in_str  );

FILE *pyscannerYYget_out (void );

void pyscannerYYset_out  (FILE * out_str  );

yy_size_t pyscannerYYget_leng (void );

char *pyscannerYYget_text (void );

int pyscannerYYget_lineno (void );

void pyscannerYYset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int pyscannerYYwrap (void );
#else
extern int pyscannerYYwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( pyscannerYYtext, pyscannerYYleng, 1, pyscannerYYout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( pyscannerYYin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( pyscannerYYin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, pyscannerYYin))==0 && ferror(pyscannerYYin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(pyscannerYYin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int pyscannerYYlex (void);

#define YY_DECL int pyscannerYYlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after pyscannerYYtext and pyscannerYYleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( pyscannerYYleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(pyscannerYYtext[pyscannerYYleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)pyscannerYYalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in pyscannerYYlex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! pyscannerYYin )
			pyscannerYYin = stdin;

		if ( ! pyscannerYYout )
			pyscannerYYout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			pyscannerYYensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				pyscannerYY_create_buffer(pyscannerYYin,YY_BUF_SIZE );
		}

		pyscannerYY_load_buffer_state( );
		}

	{
#line 538 "pyscanner.l"


  /* ------------ Function recognition rules -------------- */

#line 2094 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pyscanner.cpp"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of pyscannerYYtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 496 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 495 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */

case 1:
YY_RULE_SETUP
#line 544 "pyscanner.l"
{ // start of a function/method definition with indent
      			  DBG_CTX((stderr,"Found def at %d\n",yyLineNr));
      			  g_indent=computeIndent(pyscannerYYtext);
			  searchFoundDef();
			  BEGIN( FunctionDec );
      			}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 550 "pyscanner.l"
{ // start of a function/method definition
			  searchFoundDef();
			  BEGIN( FunctionDec );
                        }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 555 "pyscanner.l"
{ // start of a class definition with indent
       			  DBG_CTX((stderr,"Found class at %d\n",yyLineNr));
      			  g_indent=computeIndent(pyscannerYYtext);
			  searchFoundClass();
			  BEGIN( ClassDec ) ;
       			}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 561 "pyscanner.l"
{  // start of a class definition
			  searchFoundClass();
			  BEGIN( ClassDec ) ;
                       }
	YY_BREAK
case 5:
#line 566 "pyscanner.l"
case 6:
YY_RULE_SETUP
#line 566 "pyscanner.l"
{ // start of an from import
			  g_packageCommentAllowed = FALSE;
                          BEGIN( FromMod );
                       }
	YY_BREAK
case 7:
#line 572 "pyscanner.l"
case 8:
YY_RULE_SETUP
#line 572 "pyscanner.l"
{ // start of an import statement
			  g_packageCommentAllowed = FALSE;
                          BEGIN( Import );
                       }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 576 "pyscanner.l"
{ // property
      			current->section   = Entry::VARIABLE_SEC;
  			current->mtype     = Property;
			current->name      = QCString(pyscannerYYtext).stripWhiteSpace();
			current->fileName  = yyFileName;
			current->startLine = yyLineNr;
			current->bodyLine  = yyLineNr;
			g_packageCommentAllowed = FALSE;
			BEGIN(VariableDec);
       	              }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 586 "pyscanner.l"
{ // variable
                        if (g_search_count) REJECT;
      			g_indent=computeIndent(pyscannerYYtext);
      			current->section   = Entry::VARIABLE_SEC;
			current->name      = QCString(pyscannerYYtext).stripWhiteSpace();
			current->fileName  = yyFileName;
			current->startLine = yyLineNr;
			current->bodyLine  = yyLineNr;
			g_packageCommentAllowed = FALSE;
			BEGIN(VariableDec);
      		      }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 597 "pyscanner.l"
{ // list of variables, we cannot place the default value
                                                               // so we will skip it later on in a general rule
                                                               // Also note ")" this is to catch also (a,b). the "("
                                                               // is caught in the rule: [(], the ")" will be handled in [)]
                        if (g_search_count > 1) REJECT;
      			g_indent=computeIndent(pyscannerYYtext);
      			current->section   = Entry::VARIABLE_SEC;
			current->name      = QCString(pyscannerYYtext).stripWhiteSpace();
			current->fileName  = yyFileName;
			current->startLine = yyLineNr;
			current->bodyLine  = yyLineNr;
			g_packageCommentAllowed = FALSE;
			newVariable();
      		      }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 611 "pyscanner.l"
{ // start of a single quoted string
       		        g_stringContext=YY_START;
		        g_copyString=0;
			g_packageCommentAllowed = FALSE;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 617 "pyscanner.l"
{ // start of a double quoted string
       	                g_stringContext=YY_START;
			g_copyString=0;
			g_packageCommentAllowed = FALSE;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 623 "pyscanner.l"
{
       			gstat=TRUE;
      		      }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 626 "pyscanner.l"
{ // Unix type script comment
                        if (yyLineNr != 1) REJECT;
      		      }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 629 "pyscanner.l"
{ // normal comment 
			g_packageCommentAllowed = FALSE;
      		      }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 632 "pyscanner.l"
{ // some other identifier
			g_packageCommentAllowed = FALSE;
		      }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 635 "pyscanner.l"
{
      			g_curIndent=computeIndent(pyscannerYYtext);
                      }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 639 "pyscanner.l"
{ // new line
                        lineCount();
                      }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 643 "pyscanner.l"
{ // start of a comment block
			initTriDoubleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 648 "pyscanner.l"
{ // start of a comment block
			initTriSingleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 22:
/* rule 22 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_bp + 2);
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 653 "pyscanner.l"
{  // start of a special comment
      			g_curIndent=computeIndent(pyscannerYYtext);
			g_packageCommentAllowed = FALSE;
			initSpecialBlock();
			BEGIN(SpecialComment);
                      }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 659 "pyscanner.l"
{ // we have to do something with (
                        g_search_count += 1;
                      }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 662 "pyscanner.l"
{ // we have to do something with )
                        g_search_count -= 1;
                      }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 665 "pyscanner.l"
{ // any other character...
                        // This is the major default
                        // that should catch everything
                        // else in Body.
                      }
	YY_BREAK


case 26:
YY_RULE_SETUP
#line 673 "pyscanner.l"
{ // python3 style imports
                      }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 675 "pyscanner.l"
{ // from package import 
                        g_packageName=pyscannerYYtext;
		      }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 678 "pyscanner.l"
{
    			BEGIN(FromModItem);
    		      }
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 681 "pyscanner.l"
{
                        incLineNr();
                        BEGIN(Search);
                      }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 685 "pyscanner.l"
{
		      }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 687 "pyscanner.l"
{
                        unput(*pyscannerYYtext);
                        BEGIN(Search);
                      }
	YY_BREAK


case 32:
YY_RULE_SETUP
#line 694 "pyscanner.l"
{ // import all
                  QCString item=g_packageName;
		  current->name=removeRedundantWhiteSpace(substitute(item,".","::"));
		  current->fileName = yyFileName; 
		  //printf("Adding using directive: found:%s:%d name=%s\n",yyFileName.data(),yyLineNr,current->name.data());
		  current->section=Entry::USINGDIR_SEC;
		  current_root->addSubEntry(current);
		  current = new Entry ;
		  initEntry();
                  BEGIN(Search);
    		}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 705 "pyscanner.l"
{
                  QCString item=g_packageName+"."+pyscannerYYtext;
		  current->name=removeRedundantWhiteSpace(substitute(item,".","::"));
		  current->fileName = yyFileName; 
		  //printf("Adding using declaration: found:%s:%d name=%s\n",yyFileName.data(),yyLineNr,current->name.data());
		  current->section=Entry::USINGDECL_SEC;
		  current_root->addSubEntry(current);
		  current = new Entry ;
		  initEntry();
		}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 715 "pyscanner.l"
{
                  QCString item=g_packageName+"."+pyscannerYYtext;
		  current->name=removeRedundantWhiteSpace(substitute(item,".","::"));
		  current->fileName = yyFileName; 
		  //printf("Adding using declaration: found:%s:%d name=%s\n",yyFileName.data(),yyLineNr,current->name.data());
		  current->section=Entry::USINGDECL_SEC;
		  current_root->addSubEntry(current);
		  current = new Entry ;
		  initEntry();
                  BEGIN(Search);
		}
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 726 "pyscanner.l"
{
                  incLineNr();
                  BEGIN(Search);
                }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 730 "pyscanner.l"
{
		}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 732 "pyscanner.l"
{ 
  		}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 734 "pyscanner.l"
{
                  unput(*pyscannerYYtext);
                  BEGIN(Search);
                }
	YY_BREAK


case 39:
YY_RULE_SETUP
#line 741 "pyscanner.l"
{
			current->name=removeRedundantWhiteSpace(substitute(pyscannerYYtext,".","::"));
			current->fileName = yyFileName; 
			//printf("Adding using declaration: found:%s:%d name=%s\n",yyFileName.data(),yyLineNr,current->name.data());
			current->section=Entry::USINGDECL_SEC;
			current_root->addSubEntry(current);
			current = new Entry ;
			initEntry();
			BEGIN(Search);
                      }
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 751 "pyscanner.l"
{
                  incLineNr();
                  BEGIN(Search);
                }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 755 "pyscanner.l"
{
		}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 757 "pyscanner.l"
{
                  unput(*pyscannerYYtext);
                  BEGIN(Search);
                }
	YY_BREAK


case 43:
YY_RULE_SETUP
#line 764 "pyscanner.l"
{
                        DBG_CTX((stderr,"Found instance method variable %s in %s at %d\n",&pyscannerYYtext[5],current_root->name.data(),yyLineNr));
			current->name=&pyscannerYYtext[5];
			current->section=Entry::VARIABLE_SEC;
			current->fileName  = yyFileName;
			current->startLine = yyLineNr;
			current->bodyLine  = yyLineNr;
			current->type.resize(0);
			if (current->name.at(0)=='_') // mark as private
			{
			  current->protection=Private;
			}
			newEntry();
                      }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 778 "pyscanner.l"
{
                        DBG_CTX((stderr,"Found class method variable %s in %s at %d\n",&pyscannerYYtext[4],current_root->name.data(),yyLineNr));
			current->name=&pyscannerYYtext[4];
			current->section=Entry::VARIABLE_SEC;
			current->fileName  = yyFileName;
			current->startLine = yyLineNr;
			current->bodyLine  = yyLineNr;
			current->type.resize(0);
			if (current->name.at(0)=='_') // mark as private
			{
			  current->protection=Private;
			}
			newEntry();
                      }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 792 "pyscanner.l"
{ // start of a comment block
			initTriDoubleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 797 "pyscanner.l"
{ // start of a comment block
			initTriSingleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 47:
/* rule 47 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_bp + 2);
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 802 "pyscanner.l"
{  // start of a special comment
			initSpecialBlock();
			BEGIN(SpecialComment);
                      }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 806 "pyscanner.l"
{ // #
	              }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 808 "pyscanner.l"
{ // start of a single quoted string
       			g_stringContext=YY_START;
			g_copyString=0;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 813 "pyscanner.l"
{ // start of a double quoted string
       			g_stringContext=YY_START;
			g_copyString=0;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
#line 818 "pyscanner.l"
{ incLineNr(); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 819 "pyscanner.l"
// identifiers
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 820 "pyscanner.l"
// other uninteresting stuff
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 821 "pyscanner.l"
// anything else
	YY_BREAK


case 55:
/* rule 55 can match eol */
YY_RULE_SETUP
#line 825 "pyscanner.l"
{
                        DBG_CTX((stderr,"indent %d<=%d\n",computeIndent(&pyscannerYYtext[1]),g_indent));
                        if (computeIndent(&pyscannerYYtext[1])<=g_indent) 
			{
			  int i;
			  for (i=(int)pyscannerYYleng-1;i>=0;i--)
			  {
			    unput(pyscannerYYtext[i]);
			  }
			  endOfDef();
			  //YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                          BEGIN(Search);
			}
			else
			{
                          incLineNr();
      		          current->program+=pyscannerYYtext;
			}
                      }
	YY_BREAK
case 56:
/* rule 56 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_cp - 2);
(yy_c_buf_p) = yy_cp -= 2;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 844 "pyscanner.l"
{
                        if (computeIndent(&pyscannerYYtext[1])<=g_indent)
			{
			  int i;
			  for (i=(int)pyscannerYYleng-1;i>=0;i--)
			  {
			    unput(pyscannerYYtext[i]);
			  }
			  endOfDef();
			  //YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                          BEGIN(Search);
			}
			else
			{
			  incLineNr();
      		          current->program+=pyscannerYYtext;
			}
      		      }
	YY_BREAK
case YY_STATE_EOF(FunctionBody):
#line 862 "pyscanner.l"
{
			endOfDef();
			yyterminate();
      		      }
	YY_BREAK
case 57:
/* rule 57 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 866 "pyscanner.l"
{ // skip empty line
      		        current->program+=pyscannerYYtext;
      	              }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 869 "pyscanner.l"
{ // something at indent >0
      		        current->program+=pyscannerYYtext;
			g_curIndent = computeIndent(pyscannerYYtext);
                        if (g_curIndent<=g_indent) 
			  // jumped out of the function
			{
			  endOfDef(1);
                          BEGIN(Search);
			}
      		      }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 879 "pyscanner.l"
{ // start of a single quoted string
      		        current->program+=pyscannerYYtext;
       			g_stringContext=YY_START;
		        g_specialBlock = FALSE; 
			g_copyString=&current->program;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 886 "pyscanner.l"
{ // start of a double quoted string
      		        current->program+=pyscannerYYtext;
       			g_stringContext=YY_START;
		        g_specialBlock = FALSE; 
			g_copyString=&current->program;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 893 "pyscanner.l"
{ // non-special stuff
      		        current->program+=pyscannerYYtext;
		        g_specialBlock = FALSE; 
                      }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 897 "pyscanner.l"
{ // normal comment 
      		        current->program+=pyscannerYYtext;
      		      }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 900 "pyscanner.l"
{ // comment half way
      		        current->program+=pyscannerYYtext;
                      }
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
#line 903 "pyscanner.l"
{ 
			incLineNr(); 
      		        current->program+=pyscannerYYtext;
		      }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 907 "pyscanner.l"
{ // any character
      		        current->program+=*pyscannerYYtext;
		        g_specialBlock = FALSE; 
                      }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 912 "pyscanner.l"
{ // start of a comment block
			current->program+=pyscannerYYtext;
			initTriDoubleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 918 "pyscanner.l"
{ // start of a comment block
			current->program+=pyscannerYYtext;
			initTriSingleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 68:
/* rule 68 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_bp + 2);
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 924 "pyscanner.l"
{  // start of a special comment
			initSpecialBlock();
			BEGIN(SpecialComment);
                      }
	YY_BREAK


case 69:
YY_RULE_SETUP
#line 933 "pyscanner.l"
{
			      //found function name
			      if (current->type.isEmpty()) 
			      {
				  current->type = "def";
			      }
			      current->name = pyscannerYYtext;
			      current->name = current->name.stripWhiteSpace();
			      newFunction();
                            }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 943 "pyscanner.l"
{ // function without arguments
			      g_specialBlock = TRUE; // expecting a docstring
			      bodyEntry = current;
                              current->bodyLine  = yyLineNr;
                              BEGIN( FunctionBody );
			    }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 950 "pyscanner.l"
{
			       BEGIN( FunctionParams );
		            }
	YY_BREAK


case 72:
YY_RULE_SETUP
#line 956 "pyscanner.l"
{
                        }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 959 "pyscanner.l"
{ // Name of parameter
			  lineCount();
			  Argument *a = new Argument;
			  current->argList->append(a);
			  current->argList->getLast()->name = QCString(pyscannerYYtext).stripWhiteSpace();
			  current->argList->getLast()->type = "";
                        }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 966 "pyscanner.l"
{ // default value
                          // TODO: this rule is too simple, need to be able to
                          // match things like =")" as well!
			  g_defVal.resize(0);
			  g_braceCount=0;
			  BEGIN(FunctionParamDefVal);
      			}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 974 "pyscanner.l"
{ // end of parameter list
        		  current->args = argListToString(current->argList);
                        }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 978 "pyscanner.l"
{
			  g_specialBlock = TRUE; // expecting a docstring
			  bodyEntry = current;
                          current->bodyLine  = yyLineNr;
                          BEGIN( FunctionBody );
                        }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 984 "pyscanner.l"
{ // a comment
			}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 986 "pyscanner.l"
{ // Default rule inside arguments.
                        }
	YY_BREAK


case 79:
YY_RULE_SETUP
#line 992 "pyscanner.l"
{ // internal opening brace
       			  g_braceCount++;
			  g_defVal+=*pyscannerYYtext;
       			}
	YY_BREAK
case 80:
#line 997 "pyscanner.l"
case 81:
YY_RULE_SETUP
#line 997 "pyscanner.l"
{
       			  if (g_braceCount==0)  // end of default argument
			  {
			    if (current->argList->getLast())
			    {
			      current->argList->getLast()->defval=g_defVal.stripWhiteSpace();
			    }
			    if (*pyscannerYYtext == ')')
			      current->args = argListToString(current->argList);
			    BEGIN(FunctionParams);
			  }
			  else // continue
			  {
			    if (*pyscannerYYtext == ')')g_braceCount--;
			    g_defVal+=*pyscannerYYtext;
			  }
       			}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 1014 "pyscanner.l"
{
			    g_defVal+=*pyscannerYYtext;
       			}
	YY_BREAK
case 83:
/* rule 83 can match eol */
YY_RULE_SETUP
#line 1017 "pyscanner.l"
{
       			    g_defVal+=*pyscannerYYtext;
			    incLineNr();
       			}
	YY_BREAK


case 84:
/* rule 84 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_bp + 1);
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 1025 "pyscanner.l"
{ // new def at indent 0
                        incLineNr();
			endOfDef();
			//g_hideClassDocs = FALSE;
			//YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                        BEGIN(Search);
                      }
	YY_BREAK
case 85:
/* rule 85 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_bp + 1);
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 1032 "pyscanner.l"
{  // start of a special comment at indent 0
                        incLineNr();
			endOfDef();
			//g_hideClassDocs = FALSE;
			//YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                        BEGIN(Search);
                      }
	YY_BREAK
case 86:
/* rule 86 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 1039 "pyscanner.l"
{ // skip empty line
      		        current->program+=pyscannerYYtext;
      	              }
	YY_BREAK
case YY_STATE_EOF(ClassBody):
#line 1042 "pyscanner.l"
{
			endOfDef();
			yyterminate();
      		      }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 1046 "pyscanner.l"
{ // something at indent >0
                        g_curIndent=computeIndent(pyscannerYYtext);
			DBG_CTX((stderr,"g_curIndent=%d g_indent=%d\n",g_curIndent,g_indent));
                        if (g_curIndent<=g_indent) 
			  // jumped out of the class/method
			{
			  endOfDef(1);
			  g_indent=g_curIndent;
			  // make sure the next rule matches ^...
			  //YY_CURRENT_BUFFER->yy_at_bol=TRUE;
			  //g_hideClassDocs = FALSE;
                          BEGIN(Search);
			}
			else
			{
      		          current->program+=pyscannerYYtext;
			}
      		      }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 1064 "pyscanner.l"
{ // start of a single quoted string
      		        current->program+=*pyscannerYYtext;
       			g_stringContext=YY_START;
		        g_specialBlock = FALSE; 
			g_copyString=&current->program;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 1071 "pyscanner.l"
{ // start of a double quoted string
      		        current->program+=*pyscannerYYtext;
       			g_stringContext=YY_START;
		        g_specialBlock = FALSE; 
			g_copyString=&current->program;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 1078 "pyscanner.l"
{ // non-special stuff
      		        current->program+=pyscannerYYtext;
		        g_specialBlock = FALSE; 
			//g_hideClassDocs = FALSE;
                      }
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 1083 "pyscanner.l"
{ 
      		        current->program+=*pyscannerYYtext;
			incLineNr(); 
		      }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 1087 "pyscanner.l"
{ // normal comment
      		        current->program+=pyscannerYYtext;
                      }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 1090 "pyscanner.l"
{ // any character
		        g_specialBlock = FALSE; 
      		        current->program+=*pyscannerYYtext;
                      }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 1094 "pyscanner.l"
{ // start of a comment block
      		        //if (!g_hideClassDocs) 
			current->program+=pyscannerYYtext;
			initTriDoubleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 1101 "pyscanner.l"
{ // start of a comment block
      		        //if (!g_hideClassDocs) 
			current->program+=pyscannerYYtext;
			initTriSingleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK

case 96:
YY_RULE_SETUP
#line 1109 "pyscanner.l"
{
			  if (current->type.isEmpty()) 
			  {
			      current->type = "class";
			  }

			  current->section = Entry::CLASS_SEC;
			  current->name = pyscannerYYtext;

			  // prepend scope in case of nested classes
			  if (current_root->section&Entry::SCOPE_MASK)
			  {
			    //printf("*** Prepending scope %s to class %s\n",current_root->name.data(),current->name.data());
			    current->name.prepend(current_root->name+"::");
			  }
			  
			  current->name = current->name.stripWhiteSpace();
			  current->fileName = yyFileName;        
			  docBlockContext   = YY_START;
			  docBlockInBody    = FALSE;
			  docBlockJavaStyle = FALSE;
			  docBlock.resize(0);

			  BEGIN(ClassInheritance);                 
                        }
	YY_BREAK

case 97:
YY_RULE_SETUP
#line 1136 "pyscanner.l"
{ // syntactic sugar for the list
                       }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 1139 "pyscanner.l"
{ // begin of the class definition
			 g_specialBlock = TRUE; // expecting a docstring
                         current->bodyLine  = yyLineNr;
			 current->program.resize(0);
      			 BEGIN(ClassCaptureIndent);
                       }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 1146 "pyscanner.l"
{
                         current->extends->append(
					      new BaseInfo(substitute(pyscannerYYtext,".","::"),Public,Normal)
					    );
                         //Has base class-do stuff
                       }
	YY_BREAK


case 100:
/* rule 100 can match eol */
YY_RULE_SETUP
#line 1156 "pyscanner.l"
{
                                 // Blankline - ignore, keep looking for indentation.
				 lineCount();
      				 current->program+=pyscannerYYtext;
                               }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 1162 "pyscanner.l"
{ // start of a comment block
				 initTriDoubleQuoteBlock();
      				 current->program+=pyscannerYYtext;
			 	 BEGIN(TripleComment);
                      	       }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 1168 "pyscanner.l"
{ // start of a comment block
			         initTriSingleQuoteBlock();
      				 current->program+=pyscannerYYtext;
			         BEGIN(TripleComment);
                               }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 1174 "pyscanner.l"
{
      				 current->program+=pyscannerYYtext;
			         //current->startLine = yyLineNr;
				 g_curIndent=computeIndent(pyscannerYYtext);
				 bodyEntry = current;
				 DBG_CTX((stderr,"setting indent %d\n",g_curIndent));
				 //printf("current->program=[%s]\n",current->program.data());
				 //g_hideClassDocs = TRUE;
			         BEGIN(ClassBody);
                               }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 1185 "pyscanner.l"
{
				 
				 // Just pushback an empty class, and
				 // resume parsing the body.
                                 newEntry();
      				 current->program+=pyscannerYYtext;

				 // printf("Failed to find indent - skipping!");
				 BEGIN( Search );
                               }
	YY_BREAK


case 105:
YY_RULE_SETUP
#line 1199 "pyscanner.l"
{ // the assignment operator
                        //printf("====== VariableDec at line %d\n",yyLineNr);
                        g_start_init = TRUE;
			current->initializer = pyscannerYYtext;
			current->initializer += " ";
                      }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 1205 "pyscanner.l"
{ // spaces
	              }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 1207 "pyscanner.l"
{ // integer value
			current->type = "int";
			current->initializer += pyscannerYYtext;
			BEGIN(VariableEnd);
		      }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 1212 "pyscanner.l"
{ // floating point value
			current->type = "float";
			current->initializer += pyscannerYYtext;
			BEGIN(VariableEnd);
		      }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 1217 "pyscanner.l"
{ // boolean value
			current->type = "bool";
			current->initializer += pyscannerYYtext;
			BEGIN(VariableEnd);
		      }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 1222 "pyscanner.l"
{ // string
			current->type = "string";
			current->initializer += pyscannerYYtext;
			g_copyString=&current->initializer;
       			g_stringContext=VariableEnd;
                        BEGIN( SingleQuoteString );
     		      }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 1229 "pyscanner.l"
{ // string
			current->type = "string";
			current->initializer += pyscannerYYtext;
			g_copyString=&current->initializer;
       			g_stringContext=VariableEnd;
                        BEGIN( DoubleQuoteString );
     		      }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 1236 "pyscanner.l"
{ // start of a comment block
			current->type = "string";
			current->initializer += pyscannerYYtext;
			g_doubleQuote=TRUE;
			g_copyString=&current->initializer;
       			g_stringContext=VariableEnd;
			BEGIN(TripleString);
                      }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 1245 "pyscanner.l"
{ // start of a comment block
			current->type = "string";
			current->initializer += pyscannerYYtext;
			g_doubleQuote=FALSE;
			g_copyString=&current->initializer;
       			g_stringContext=VariableEnd;
			BEGIN(TripleString);
                      }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 1253 "pyscanner.l"
{ // tuple, only when direct after =
                        if (current->mtype!=Property && g_start_init)
			{
			  current->type = "tuple";
			}
      		        current->initializer+=*pyscannerYYtext;
                        g_atomStart='(';
			g_atomEnd=')';
			g_atomCount=1;
			BEGIN( VariableAtom );
                      }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 1264 "pyscanner.l"
{ // list
                        if (g_start_init) current->type = "list";
      		        current->initializer+=*pyscannerYYtext;
                        g_atomStart='[';
			g_atomEnd=']';
			g_atomCount=1;
			BEGIN( VariableAtom );
                      }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 1272 "pyscanner.l"
{ // dictionary
                        if (g_start_init) current->type = "dictionary";
      		        current->initializer+=*pyscannerYYtext;
                        g_atomStart='{';
			g_atomEnd='}';
			g_atomCount=1;
			BEGIN( VariableAtom );
                      }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 1280 "pyscanner.l"
{ // comment
                        BEGIN( VariableEnd ); 
                      }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 1283 "pyscanner.l"
{
                        g_start_init = FALSE;
      		        current->initializer+=pyscannerYYtext;
	              }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 1287 "pyscanner.l"
{
                        g_start_init = FALSE;
      		        current->initializer+=*pyscannerYYtext;
                      }
	YY_BREAK
case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 1291 "pyscanner.l"
{
     		        unput('\n');
     			BEGIN( VariableEnd );
     		      }
	YY_BREAK


case 121:
YY_RULE_SETUP
#line 1298 "pyscanner.l"
{
      		        current->initializer+=*pyscannerYYtext;
                        if (g_atomStart==*pyscannerYYtext)
			{
			  g_atomCount++;
			}
                      }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 1305 "pyscanner.l"
{
      		        current->initializer+=*pyscannerYYtext;
                        if (g_atomEnd==*pyscannerYYtext)
			{
			  g_atomCount--;
			}
			if (g_atomCount==0)
			{
                          g_start_init = FALSE;
			  BEGIN(VariableDec);
			}
                      }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 1317 "pyscanner.l"
{ // start of a comment block
                        g_specialBlock = FALSE;
			current->program+=pyscannerYYtext;
			initTriDoubleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 1324 "pyscanner.l"
{ // start of a comment block
                        g_specialBlock = FALSE;
			current->program+=pyscannerYYtext;
			initTriSingleQuoteBlock();
			BEGIN(TripleComment);
                      }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 1330 "pyscanner.l"
{
       			g_stringContext=YY_START;
			current->initializer+="'";
			g_copyString=&current->initializer;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 1336 "pyscanner.l"
{
       			g_stringContext=YY_START;
			current->initializer+="\"";
			g_copyString=&current->initializer;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 1342 "pyscanner.l"
{
      		        current->initializer+=pyscannerYYtext;
	              }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 1345 "pyscanner.l"
{
      		        current->initializer+=*pyscannerYYtext;
                      }
	YY_BREAK
case 129:
/* rule 129 can match eol */
YY_RULE_SETUP
#line 1348 "pyscanner.l"
{
      		        current->initializer+=*pyscannerYYtext;
     			incLineNr();
     		      }
	YY_BREAK


case 130:
/* rule 130 can match eol */
YY_RULE_SETUP
#line 1356 "pyscanner.l"
{
                        incLineNr();
			newVariable();
                        BEGIN(Search);
                      }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 1361 "pyscanner.l"
{ 
                        unput(*pyscannerYYtext);
			newVariable();
                        BEGIN(Search);
      		      }
	YY_BREAK
case YY_STATE_EOF(VariableEnd):
#line 1366 "pyscanner.l"
{ yyterminate();
                        newEntry();
                      }
	YY_BREAK


case 132:
#line 1373 "pyscanner.l"
case 133:
YY_RULE_SETUP
#line 1373 "pyscanner.l"
{
			  // printf("Expected module block %d special=%d\n",g_expectModuleDocs,g_specialBlock);
			  if (g_doubleQuote==(pyscannerYYtext[0]=='"')) 
			  {
			    if (g_specialBlock) // expecting a docstring
			    {
			      QCString actualDoc=docBlock;
			      if (!docBlockSpecial) // legacy unformatted docstring
			      {
			        actualDoc.prepend("\\verbatim ");
			        actualDoc.append("\\endverbatim ");
			      }
			      //printf("-------> current=%p bodyEntry=%p\n",current,bodyEntry);
			      handleCommentBlock(actualDoc, FALSE);
			    }
			    else if (g_packageCommentAllowed) // expecting module docs
			    {
			      QCString actualDoc=docBlock;
			      if (!docBlockSpecial) // legacy unformatted docstring
			      {
			        actualDoc.prepend("\\verbatim ");
			        actualDoc.append("\\endverbatim ");
			      }
			      actualDoc.prepend("\\namespace "+g_moduleScope+"\\_linebr ");
			      handleCommentBlock(actualDoc, FALSE);
			    }
			    if ((docBlockContext==ClassBody /*&& !g_hideClassDocs*/) ||
				docBlockContext==FunctionBody)
			    {
			      current->program+=docBlock;
			      current->program+=pyscannerYYtext;
			    }
                            //if (g_hideClassDocs)
			    //{
                            //  current->startLine = yyLineNr;
			    //}
			    //g_hideClassDocs=FALSE;
			    BEGIN(docBlockContext);
			  }
                          else 
			  {
                            docBlock += pyscannerYYtext;
                          }
			  g_packageCommentAllowed = FALSE;
                        }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 1420 "pyscanner.l"
{ // leading whitespace
      			  int indent = computeIndent(pyscannerYYtext);
			  if (indent>=g_curIndent)
			  { // strip g_curIndent amount of whitespace
			    int i;
			    for (i=0;i<indent-g_curIndent;i++) docBlock+=' ';
			    DBG_CTX((stderr,"stripping indent %d\n",g_curIndent));
			  }
			  else
			  {
			    DBG_CTX((stderr,"not stripping: %d<%d\n",indent,g_curIndent));
			    docBlock += pyscannerYYtext;
			  }
      			}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 1434 "pyscanner.l"
{
			  docBlock += pyscannerYYtext;
                        }
	YY_BREAK
case 136:
/* rule 136 can match eol */
YY_RULE_SETUP
#line 1437 "pyscanner.l"
{
      			  incLineNr();
			  docBlock += pyscannerYYtext;
      			}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 1441 "pyscanner.l"
{ // espaced char
			  docBlock += pyscannerYYtext;
      			}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 1444 "pyscanner.l"
{
			  docBlock += pyscannerYYtext;
      			}
	YY_BREAK


case 139:
YY_RULE_SETUP
#line 1450 "pyscanner.l"
{ // skip leading hashes
      			}
	YY_BREAK
case 140:
/* rule 140 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pyscannerYYtext */
YY_LINENO_REWIND_TO(yy_bp + 1);
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up pyscannerYYtext again */
YY_RULE_SETUP
#line 1452 "pyscanner.l"
{ // continuation of the comment on the next line
      			  docBlock+='\n';
			  docBrief = FALSE;
                          startCommentBlock(FALSE);
			  incLineNr();
      			}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 1458 "pyscanner.l"
{ // any other stuff
      			  docBlock+=pyscannerYYtext;
      			}
	YY_BREAK
case 142:
/* rule 142 can match eol */
YY_RULE_SETUP
#line 1461 "pyscanner.l"
{ // new line that ends the comment
			  handleCommentBlock(docBlock, docBrief);
      			  incLineNr();
			  BEGIN(docBlockContext);
      			}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 1466 "pyscanner.l"
{ // anything we missed
      			  docBlock+=*pyscannerYYtext;
      			}
	YY_BREAK


case 144:
/* rule 144 can match eol */
YY_RULE_SETUP
#line 1472 "pyscanner.l"
{ // line continuation
      			         addToString(pyscannerYYtext);
      				 incLineNr();
                               }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 1476 "pyscanner.l"
{ // espaced char
      			         addToString(pyscannerYYtext);
                               }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 1479 "pyscanner.l"
{ // tripple double quotes
      			         addToString(pyscannerYYtext);
      			       }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 1482 "pyscanner.l"
{ // end of the string
      			         addToString(pyscannerYYtext);
      		                 BEGIN(g_stringContext);
                               }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 1486 "pyscanner.l"
{ // normal chars
      			         addToString(pyscannerYYtext);
                               }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 1489 "pyscanner.l"
{ // normal char
      			         addToString(pyscannerYYtext);
                               }
	YY_BREAK


case 150:
/* rule 150 can match eol */
YY_RULE_SETUP
#line 1495 "pyscanner.l"
{ // line continuation
      			         addToString(pyscannerYYtext);
      				 incLineNr();
                               }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 1499 "pyscanner.l"
{ // espaced char
      			         addToString(pyscannerYYtext);
                               }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 1502 "pyscanner.l"
{ // tripple single quotes
      			         addToString(pyscannerYYtext);
      			       }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 1505 "pyscanner.l"
{ // end of the string
      			         addToString(pyscannerYYtext);
      		                 BEGIN(g_stringContext);
                               }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 1509 "pyscanner.l"
{ // normal chars
      			         addToString(pyscannerYYtext);
                               }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 1512 "pyscanner.l"
{ // normal char
      			         addToString(pyscannerYYtext);
                               }
	YY_BREAK


case 156:
#line 1519 "pyscanner.l"
case 157:
YY_RULE_SETUP
#line 1519 "pyscanner.l"
{
                          *g_copyString += pyscannerYYtext;
			  if (g_doubleQuote==(pyscannerYYtext[0]=='"')) 
			  {
			    BEGIN(g_stringContext);
			  }
                        }
	YY_BREAK
case 158:
/* rule 158 can match eol */
YY_RULE_SETUP
#line 1528 "pyscanner.l"
{
			  lineCount();
                          *g_copyString += pyscannerYYtext;
                        }
	YY_BREAK
case 159:
/* rule 159 can match eol */
YY_RULE_SETUP
#line 1532 "pyscanner.l"
{
      			  incLineNr();
                          *g_copyString += pyscannerYYtext;
      			}
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 1536 "pyscanner.l"
{
                          *g_copyString += *pyscannerYYtext;
      			}
	YY_BREAK

/* ------------ End rules -------------- */
/*
<*>({NONEMPTY}|{EXPCHAR}|{BB})           { // This should go one character at a time.
				 // printf("[pyscanner] '%s' [ state %d ]  [line %d] no match\n",
				 //       pyscannerYYtext, YY_START, yyLineNr);

                               }
  */
case 161:
/* rule 161 can match eol */
YY_RULE_SETUP
#line 1551 "pyscanner.l"
{
				 //printf("[pyscanner] %d NEWLINE [line %d] no match\n",
				 //       YY_START, yyLineNr);

                                 lineCount();
                               }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 1558 "pyscanner.l"
{
				 //printf("[pyscanner] '%s' [ state %d ]  [line %d] no match\n",
				 //       pyscannerYYtext, YY_START, yyLineNr);

                               }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 1565 "pyscanner.l"
ECHO;
	YY_BREAK
#line 3853 "/cygdrive/d/Dave/Linux/Cygwin/cygwin_auto_maintainer/doxygen/doxygen-1.8.11-2.i686/build/generated_src/pyscanner.cpp"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(Search):
			case YY_STATE_EOF(SearchMemVars):
			case YY_STATE_EOF(TryClassDocString):
			case YY_STATE_EOF(TripleComment):
			case YY_STATE_EOF(SpecialComment):
			case YY_STATE_EOF(FunctionDec):
			case YY_STATE_EOF(FunctionParams):
			case YY_STATE_EOF(FunctionParamDefVal):
			case YY_STATE_EOF(ClassDec):
			case YY_STATE_EOF(ClassInheritance):
			case YY_STATE_EOF(ClassCaptureIndent):
			case YY_STATE_EOF(VariableDec):
			case YY_STATE_EOF(VariableAtom):
			case YY_STATE_EOF(SingleQuoteString):
			case YY_STATE_EOF(DoubleQuoteString):
			case YY_STATE_EOF(TripleString):
			case YY_STATE_EOF(FromMod):
			case YY_STATE_EOF(FromModItem):
			case YY_STATE_EOF(Import):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed pyscannerYYin at a new source and called
			 * pyscannerYYlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = pyscannerYYin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( pyscannerYYwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * pyscannerYYtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of pyscannerYYlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			pyscannerYYrestart(pyscannerYYin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) pyscannerYYrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 496 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 496 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 495);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up pyscannerYYtext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					pyscannerYYrestart(pyscannerYYin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( pyscannerYYwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve pyscannerYYtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void pyscannerYYrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        pyscannerYYensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            pyscannerYY_create_buffer(pyscannerYYin,YY_BUF_SIZE );
	}

	pyscannerYY_init_buffer(YY_CURRENT_BUFFER,input_file );
	pyscannerYY_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void pyscannerYY_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		pyscannerYYpop_buffer_state();
	 *		pyscannerYYpush_buffer_state(new_buffer);
     */
	pyscannerYYensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	pyscannerYY_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (pyscannerYYwrap()) processing, but the only time this flag
	 * is looked at is after pyscannerYYwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void pyscannerYY_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	pyscannerYYin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE pyscannerYY_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) pyscannerYYalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pyscannerYY_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) pyscannerYYalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in pyscannerYY_create_buffer()" );

	b->yy_is_our_buffer = 1;

	pyscannerYY_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with pyscannerYY_create_buffer()
 * 
 */
    void pyscannerYY_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		pyscannerYYfree((void *) b->yy_ch_buf  );

	pyscannerYYfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a pyscannerYYrestart() or at EOF.
 */
    static void pyscannerYY_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	pyscannerYY_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then pyscannerYY_init_buffer was _probably_
     * called from pyscannerYYrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void pyscannerYY_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		pyscannerYY_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void pyscannerYYpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	pyscannerYYensure_buffer_stack();

	/* This block is copied from pyscannerYY_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from pyscannerYY_switch_to_buffer. */
	pyscannerYY_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void pyscannerYYpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	pyscannerYY_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		pyscannerYY_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void pyscannerYYensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)pyscannerYYalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in pyscannerYYensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)pyscannerYYrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in pyscannerYYensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE pyscannerYY_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) pyscannerYYalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pyscannerYY_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	pyscannerYY_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to pyscannerYYlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       pyscannerYY_scan_bytes() instead.
 */
YY_BUFFER_STATE pyscannerYY_scan_string (yyconst char * yystr )
{
    
	return pyscannerYY_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to pyscannerYYlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE pyscannerYY_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) pyscannerYYalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in pyscannerYY_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = pyscannerYY_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in pyscannerYY_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pyscannerYYtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		pyscannerYYtext[pyscannerYYleng] = (yy_hold_char); \
		(yy_c_buf_p) = pyscannerYYtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		pyscannerYYleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int pyscannerYYget_lineno  (void)
{
        
    return pyscannerYYlineno;
}

/** Get the input stream.
 * 
 */
FILE *pyscannerYYget_in  (void)
{
        return pyscannerYYin;
}

/** Get the output stream.
 * 
 */
FILE *pyscannerYYget_out  (void)
{
        return pyscannerYYout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t pyscannerYYget_leng  (void)
{
        return pyscannerYYleng;
}

/** Get the current token.
 * 
 */

char *pyscannerYYget_text  (void)
{
        return pyscannerYYtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void pyscannerYYset_lineno (int  line_number )
{
    
    pyscannerYYlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see pyscannerYY_switch_to_buffer
 */
void pyscannerYYset_in (FILE *  in_str )
{
        pyscannerYYin = in_str ;
}

void pyscannerYYset_out (FILE *  out_str )
{
        pyscannerYYout = out_str ;
}

int pyscannerYYget_debug  (void)
{
        return pyscannerYY_flex_debug;
}

void pyscannerYYset_debug (int  bdebug )
{
        pyscannerYY_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from pyscannerYYlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    pyscannerYYin = stdin;
    pyscannerYYout = stdout;
#else
    pyscannerYYin = (FILE *) 0;
    pyscannerYYout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * pyscannerYYlex_init()
     */
    return 0;
}

/* pyscannerYYlex_destroy is for both reentrant and non-reentrant scanners. */
int pyscannerYYlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		pyscannerYY_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		pyscannerYYpop_buffer_state();
	}

	/* Destroy the stack itself. */
	pyscannerYYfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    pyscannerYYfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * pyscannerYYlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *pyscannerYYalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *pyscannerYYrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void pyscannerYYfree (void * ptr )
{
	free( (char *) ptr );	/* see pyscannerYYrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 1565 "pyscanner.l"



//----------------------------------------------------------------------------

static void parseCompounds(Entry *rt)
{
  //printf("parseCompounds(%s)\n",rt->name.data());
  EntryListIterator eli(*rt->children());
  Entry *ce;
  for (;(ce=eli.current());++eli)
  {
    if (!ce->program.isEmpty())
    {
      //printf("-- %s ---------\n%s\n---------------\n",
      //  ce->name.data(),ce->program.data());
      // init scanner state
      inputString = ce->program;
      inputPosition = 0;
      pyscannerYYrestart( pyscannerYYin ) ;
      if (ce->section&Entry::COMPOUND_MASK)
      {
        current_root = ce ;
        BEGIN( Search );
      }
      else if (ce->parent())
      {
        current_root = ce->parent();
	//printf("Searching for member variables in %s parent=%s\n",
	//    ce->name.data(),ce->parent->name.data());
	BEGIN( SearchMemVars );
      }
      yyFileName = ce->fileName;
      yyLineNr   = ce->bodyLine ;
      if (current) delete current;
      current = new Entry;
      initEntry();

      groupEnterCompound(yyFileName,yyLineNr,ce->name);
      
      pyscannerYYlex() ;
      g_lexInit=TRUE;
      delete current; current=0;
      ce->program.resize(0);

      groupLeaveCompound(yyFileName,yyLineNr,ce->name);

    }
    parseCompounds(ce);
  }
}

//----------------------------------------------------------------------------


static void parseMain(const char *fileName,const char *fileBuf,Entry *rt)
{
  initParser();

  inputString = fileBuf;
  inputPosition = 0;

  protection    = Public;
  mtype         = Method;
  gstat         = FALSE;
  virt          = Normal;
  current_root  = rt;
  g_specialBlock = FALSE;


  inputFile.setName(fileName);
  if (inputFile.open(IO_ReadOnly))
  {
    yyLineNr= 1 ; 
    yyFileName = fileName;
    //setContext();
    msg("Parsing file %s...\n",yyFileName.data());

    QFileInfo fi(fileName);
    g_moduleScope = findPackageScope(fileName);
    QCString baseName=fi.baseName().utf8();
    if (baseName!="__init__") // package initializer file is not a package itself
    {
      if (!g_moduleScope.isEmpty())
      {
	g_moduleScope+="::";
      }
      g_moduleScope+=baseName;
    }

    current            = new Entry;
    initEntry();
    current->name      = g_moduleScope;
    current->section   = Entry::NAMESPACE_SEC;
    current->type      = "namespace";
    current->fileName  = yyFileName;
    current->startLine = yyLineNr;
    current->bodyLine  = yyLineNr;

    rt->addSubEntry(current);

    current_root  = current ;
    initParser();
    current       = new Entry;

    groupEnterFile(yyFileName,yyLineNr);
    
    current->reset();
    initEntry();
    pyscannerYYrestart( pyscannerYYin );
    BEGIN( Search );
    pyscannerYYlex();
    g_lexInit=TRUE;

    groupLeaveFile(yyFileName,yyLineNr);

    current_root->program.resize(0);
    delete current; current=0;

    parseCompounds(current_root);

    inputFile.close();
  }
  
}

//----------------------------------------------------------------------------

static void parsePrototype(const QCString &text)
{
  //printf("**** parsePrototype(%s) begin\n",text.data());
  if (text.isEmpty()) 
  {
    warn(yyFileName,yyLineNr,"Empty prototype found!");
    return;
  }

  g_specialBlock = FALSE;
  g_packageCommentAllowed = FALSE;

  const char *orgInputString;
  int orgInputPosition;
  YY_BUFFER_STATE orgState;
  
  // save scanner state
  orgState = YY_CURRENT_BUFFER;
  pyscannerYY_switch_to_buffer(pyscannerYY_create_buffer(pyscannerYYin,YY_BUF_SIZE));
  orgInputString = inputString; 
  orgInputPosition = inputPosition;

  // set new string
  inputString = text;
  inputPosition = 0;
  pyscannerYYrestart( pyscannerYYin );

  BEGIN( FunctionDec );

  pyscannerYYlex();
  g_lexInit=TRUE;

  current->name = current->name.stripWhiteSpace();
  if (current->section == Entry::MEMBERDOC_SEC && current->args.isEmpty())
    current->section = Entry::VARIABLEDOC_SEC;

  // restore original scanner state

  YY_BUFFER_STATE tmpBuf = YY_CURRENT_BUFFER;
  pyscannerYY_switch_to_buffer(orgState);
  pyscannerYY_delete_buffer(tmpBuf);

  inputString = orgInputString; 
  inputPosition = orgInputPosition;

  //printf("**** parsePrototype end\n");
}

void pyscanFreeScanner()
{
#if defined(YY_FLEX_SUBMINOR_VERSION) 
  if (g_lexInit)
  {
    pyscannerYYlex_destroy();
  }
#endif
}

//----------------------------------------------------------------------------

void PythonLanguageScanner::parseInput(const char *fileName,
                                       const char *fileBuf,
                                       Entry *root,
                                       bool /*sameTranslationUnit*/,
                                       QStrList & /*filesInSameTranslationUnit*/)
{
  g_thisParser = this;
  printlex(pyscannerYY_flex_debug, TRUE, __FILE__, fileName);
  ::parseMain(fileName,fileBuf,root);
  printlex(pyscannerYY_flex_debug, FALSE, __FILE__, fileName);

  // May print the AST for debugging purposes
  // printAST(global_root);
}

bool PythonLanguageScanner::needsPreprocessing(const QCString &)
{
  return FALSE;
}

void PythonLanguageScanner::parseCode(CodeOutputInterface &codeOutIntf,
    const char *scopeName,
    const QCString &input,
    SrcLangExt /*lang*/,
    bool isExampleBlock,
    const char *exampleName,
    FileDef *fileDef,
    int startLine,
    int endLine,
    bool inlineFragment,
    MemberDef *memberDef,
    bool showLineNumbers,
    Definition *searchCtx,
    bool collectXRefs
    )
{
  ::parsePythonCode(codeOutIntf,scopeName,input,isExampleBlock,exampleName,
                    fileDef,startLine,endLine,inlineFragment,memberDef,
                    showLineNumbers,searchCtx,collectXRefs);
}

void PythonLanguageScanner::parsePrototype(const char *text)
{
  ::parsePrototype(text);

}

void PythonLanguageScanner::resetCodeParserState()
{
  ::resetPythonCodeParserState();
}

//----------------------------------------------------------------------------

#if !defined(YY_FLEX_SUBMINOR_VERSION) 
//----------------------------------------------------------------------------
extern "C" { // some bogus code to keep the compiler happy
  void pyscannerYYdummy() { yy_flex_realloc(0,0); } 
}
#endif


